Skip to main content Module api Copy item path Source Abi Represents an Abi. AbiTargeting Targeting based on Abi. AcquisitionTargetingRule Represents a targeting rule of the form: User never had {scope} before. ActivateBasePlanRequest Request message for ActivateBasePlan. ActivateOneTimeProductOfferRequest Request message for ActivateOneTimeProductOffer. ActivatePurchaseOptionRequest Request message for UpdatePurchaseOptionState. ActivateSubscriptionOfferRequest Request message for ActivateSubscriptionOffer. AddTargetingRequest Request message for AddTargeting. AddTargetingResponse Response message for AddTargeting. AllUsers Object representation to describe all set of users. AndroidPublisher Central instance to access all AndroidPublisher related resource activities AndroidSdks Android api level targeting data for app recovery action targeting. Apk Information about an APK. The resource for ApksService. ApkBinary Represents the binary payload of an APK. ApkDescription Description of the created apks. ApkSet A set of apks representing a module. ApkTargeting Represents a set of apk-level targetings. ApksAddExternallyHostedRequest Request to create a new externally hosted APK. ApksAddExternallyHostedResponse Response for creating a new externally hosted APK. ApksListResponse Response listing all APKs. AppDetails The app details. The resource for DetailsService. AppEdit An app edit. The resource for EditsService. AppRecoveryAction Information about an app recovery action. AppVersionList Data format for a list of app versions. AppVersionRange Data format for a continuous range of app versions. ApplicationDataSafetyCall Writes the Safety Labels declaration of an app. ApplicationDeviceTierConfigCreateCall Creates a new device tier config for an app. ApplicationDeviceTierConfigGetCall Returns a particular device tier config. ApplicationDeviceTierConfigListCall Returns created device tier configs, ordered by descending creation time. ApplicationMethods A builder providing access to all methods supported on application resources.
It is not used directly, but through the AndroidPublisher hub. ApprecoveryAddTargetingCall Incrementally update targeting for a recovery action. Note that only the criteria selected during the creation of recovery action can be expanded. ApprecoveryCancelCall Cancel an already executing app recovery action. Note that this action changes status of the recovery action to CANCELED. ApprecoveryCreateCall Create an app recovery action with recovery status as DRAFT. Note that this action does not execute the recovery action. ApprecoveryDeployCall Deploy an already created app recovery action with recovery status DRAFT. Note that this action activates the recovery action for all targeted users and changes its status to ACTIVE. ApprecoveryListCall List all app recovery action resources associated with a particular package name and app version. ApprecoveryMethods A builder providing access to all methods supported on apprecovery resources.
It is not used directly, but through the AndroidPublisher hub. ArchiveSubscriptionRequest Deprecated: subscription archiving is not supported. AssetModuleMetadata Metadata of an asset module. AssetSliceSet Set of asset slices belonging to a single asset module. AutoRenewingBasePlanType Represents a base plan that automatically renews at the end of its subscription period. AutoRenewingPlan Information related to an auto renewing plan. BaseDetails Details of a base price pricing phase. BasePlan A single base plan for a subscription. BatchDeleteOneTimeProductOffersRequest Request message for BatchDeleteOneTimeProductOffers. BatchDeleteOneTimeProductsRequest Request message for BatchDeleteOneTimeProduct. BatchDeletePurchaseOptionsRequest Request message for BatchDeletePurchaseOption. BatchGetOneTimeProductOffersRequest Request message for the BatchGetOneTimeProductOffers endpoint. BatchGetOneTimeProductOffersResponse Response message for the BatchGetOneTimeProductOffers endpoint. BatchGetOneTimeProductsResponse Response message for the BatchGetOneTimeProducts endpoint. BatchGetOrdersResponse Response for the orders.batchGet API. BatchGetSubscriptionOffersRequest Request message for BatchGetSubscriptionOffers endpoint. BatchGetSubscriptionOffersResponse Response message for BatchGetSubscriptionOffers endpoint. BatchGetSubscriptionsResponse Response message for BatchGetSubscriptions endpoint. BatchMigrateBasePlanPricesRequest Request message for BatchMigrateBasePlanPrices. BatchMigrateBasePlanPricesResponse Response message for BatchMigrateBasePlanPrices. BatchUpdateBasePlanStatesRequest Request message for BatchUpdateBasePlanStates. BatchUpdateBasePlanStatesResponse Response message for BatchUpdateBasePlanStates. BatchUpdateOneTimeProductOfferStatesRequest Request message for BatchUpdateOneTimeProductOfferStates. BatchUpdateOneTimeProductOfferStatesResponse Response message for BatchUpdateOneTimeProductOfferStates. BatchUpdateOneTimeProductOffersRequest Request message for BatchUpdateOneTimeProductOffers. BatchUpdateOneTimeProductOffersResponse Response message for BatchUpdateOneTimeProductOffers. BatchUpdateOneTimeProductsRequest Request message for BatchUpdateOneTimeProduct. BatchUpdateOneTimeProductsResponse Response message for BatchUpdateOneTimeProduct. BatchUpdatePurchaseOptionStatesRequest Request message for BatchUpdatePurchaseOptionStates. BatchUpdatePurchaseOptionStatesResponse Response message for BatchUpdatePurchaseOptionStates. BatchUpdateSubscriptionOfferStatesRequest Request message for BatchUpdateSubscriptionOfferStates. BatchUpdateSubscriptionOfferStatesResponse Response message for BatchUpdateSubscriptionOfferStates. BatchUpdateSubscriptionOffersRequest Request message for BatchUpdateSubscriptionOffers. BatchUpdateSubscriptionOffersResponse Response message for BatchUpdateSubscriptionOffers. BatchUpdateSubscriptionsRequest Request message for BatchUpdateSubscription. BatchUpdateSubscriptionsResponse Response message for BatchUpdateSubscription. Bundle Information about an app bundle. The resource for BundlesService. BundlesListResponse Response listing all app bundles. BuyerAddress Address information for the customer, for use in tax computation. CancelAppRecoveryRequest Request message for CancelAppRecovery. CancelAppRecoveryResponse Response message for CancelAppRecovery. CancelOneTimeProductOfferRequest Request message for CancelOneTimeProductOffer. CancelSubscriptionPurchaseRequest Request for the purchases.subscriptionsv2.cancel API. CancelSubscriptionPurchaseResponse Response for the purchases.subscriptionsv2.cancel API. CancelSurveyResult Result of the cancel survey when the subscription was canceled by the user. CanceledStateContext Information specific to a subscription in the SUBSCRIPTION_STATE_CANCELED or SUBSCRIPTION_STATE_EXPIRED state. CancellationContext Cancellation context of the purchases.subscriptionsv2.cancel API. CancellationEvent Details of when the order was canceled. Comment An entry of conversation between user and developer. ConvertRegionPricesRequest Request message for ConvertRegionPrices. ConvertRegionPricesResponse Response message for ConvertRegionPrices. ConvertedOtherRegionsPrice Converted other regions prices. ConvertedRegionPrice A converted region price. CountryTargeting Country targeting specification. CreateDraftAppRecoveryRequest Request message for CreateDraftAppRecovery. DeactivateBasePlanRequest Request message for DeactivateBasePlan. DeactivateOneTimeProductOfferRequest Request message for DeactivateOneTimeProductOffer. DeactivatePurchaseOptionRequest Request message for UpdatePurchaseOptionState. DeactivateSubscriptionOfferRequest Request message for DeactivateSubscriptionOffer. DeferredItemRemoval Information related to deferred item replacement. DeferredItemReplacement Information related to deferred item replacement. DeleteOneTimeProductOfferRequest Request message for deleting an one-time product offer. DeleteOneTimeProductRequest Request message for deleting a one-time product. DeletePurchaseOptionRequest Request message for deleting a purchase option. DeobfuscationFile Represents a deobfuscation file. DeobfuscationFilesUploadResponse Responses for the upload. DeployAppRecoveryRequest Request message for DeployAppRecovery. DeployAppRecoveryResponse Response message for DeployAppRecovery. DeveloperComment Developer entry from conversation between user and developer. DeveloperInitiatedCancellation Information specific to cancellations initiated by developers. DeviceFeature Represents a device feature. DeviceFeatureTargeting Targeting for a device feature. DeviceGroup A group of devices. A group is defined by a set of device selectors. A device belongs to the group if it matches any selector (logical OR). DeviceId Identifier of a device. DeviceMetadata Characteristics of the user’s device. DeviceRam Conditions about a device’s RAM capabilities. DeviceSelector Selector for a device group. A selector consists of a set of conditions on the device that should all match (logical AND) to determine a device group eligibility. For instance, if a selector specifies RAM conditions, device model inclusion and device model exclusion, a device is considered to match if: device matches RAM conditions AND device matches one of the included device models AND device doesn’t match excluded device models DeviceSpec The device spec used to generate a system APK. DeviceTier A single device tier. Devices matching any of the device groups in device_group_names are considered to match the tier. DeviceTierConfig Configuration describing device targeting criteria for the content of an app. DeviceTierSet A set of device tiers. A tier set determines what variation of app content gets served to a specific device, for device-targeted content. You should assign a priority level to each tier, which determines the ordering by which they are evaluated by Play. See the documentation of DeviceTier.level for more details. EditApkAddexternallyhostedCall Creates a new APK without uploading the APK itself to Google Play, instead hosting the APK at a specified URL. This function is only available to organizations using Managed Play whose application is configured to restrict distribution to the organizations. EditApkListCall Lists all current APKs of the app and edit. EditApkUploadCall Uploads an APK and adds to the current edit. EditBundleListCall Lists all current Android App Bundles of the app and edit. EditBundleUploadCall Uploads a new Android App Bundle to this edit. If you are using the Google API client libraries, please increase the timeout of the http request before calling this endpoint (a timeout of 2 minutes is recommended). See Timeouts and Errors for an example in java. EditCommitCall Commits an app edit. EditCountryavailabilityGetCall Gets country availability. EditDeleteCall Deletes an app edit. EditDeobfuscationfileUploadCall Uploads a new deobfuscation file and attaches to the specified APK. EditDetailGetCall Gets details of an app. EditDetailPatchCall Patches details of an app. EditDetailUpdateCall Updates details of an app. EditExpansionfileGetCall Fetches the expansion file configuration for the specified APK. EditExpansionfilePatchCall Patches the APK’s expansion file configuration to reference another APK’s expansion file. To add a new expansion file use the Upload method. EditExpansionfileUpdateCall Updates the APK’s expansion file configuration to reference another APK’s expansion file. To add a new expansion file use the Upload method. EditExpansionfileUploadCall Uploads a new expansion file and attaches to the specified APK. EditGetCall Gets an app edit. EditImageDeleteCall Deletes the image (specified by id) from the edit. EditImageDeleteallCall Deletes all images for the specified language and image type. Returns an empty response if no images are found. EditImageListCall Lists all images. The response may be empty. EditImageUploadCall Uploads an image of the specified language and image type, and adds to the edit. EditInsertCall Creates a new edit for an app. EditListingDeleteCall Deletes a localized store listing. EditListingDeleteallCall Deletes all store listings. EditListingGetCall Gets a localized store listing. EditListingListCall Lists all localized store listings. EditListingPatchCall Patches a localized store listing. EditListingUpdateCall Creates or updates a localized store listing. EditMethods A builder providing access to all methods supported on edit resources.
It is not used directly, but through the AndroidPublisher hub. EditTesterGetCall Gets testers. Note: Testers resource does not support email lists. EditTesterPatchCall Patches testers. Note: Testers resource does not support email lists. EditTesterUpdateCall Updates testers. Note: Testers resource does not support email lists. EditTrackCreateCall Creates a new track. EditTrackGetCall Gets a track. EditTrackListCall Lists all tracks. EditTrackPatchCall Patches a track. EditTrackUpdateCall Updates a track. EditValidateCall Validates an app edit. ExpansionFile An expansion file. The resource for ExpansionFilesService. ExpansionFilesUploadResponse Response for uploading an expansion file. ExternalAccountIdentifiers User account identifier in the third-party service. ExternalAccountIds User account identifier in your app. ExternalOfferDetails Reporting details unique to the external offers program. ExternalSubscription Details of an external subscription. ExternalTransaction The details of an external transaction. ExternalTransactionAddress User’s address for the external transaction. ExternalTransactionTestPurchase Represents a transaction performed using a test account. These transactions will not be charged by Google. ExternallyHostedApk Defines an APK available for this application that is hosted externally and not uploaded to Google Play. This function is only available to organizations using Managed Play whose application is configured to restrict distribution to the organizations. ExternaltransactionCreateexternaltransactionCall Creates a new external transaction. ExternaltransactionGetexternaltransactionCall Gets an existing external transaction. ExternaltransactionMethods A builder providing access to all methods supported on externaltransaction resources.
It is not used directly, but through the AndroidPublisher hub. ExternaltransactionRefundexternaltransactionCall Refunds or partially refunds an existing external transaction. FreeTrialDetails Details of a free trial pricing phase. FullRefund A full refund of the remaining amount of a transaction. GeneratedApksListResponse Response to list generated APKs. GeneratedApksPerSigningKey Download metadata for split, standalone and universal APKs, as well as asset pack slices, signed with a given key. GeneratedAssetPackSlice Download metadata for an asset pack slice. GeneratedRecoveryApk Download metadata for an app recovery module. GeneratedSplitApk Download metadata for a split APK. GeneratedStandaloneApk Download metadata for a standalone APK. GeneratedUniversalApk Download metadata for a universal APK. GeneratedapkDownloadCall Downloads a single signed APK generated from an app bundle. GeneratedapkListCall Returns download metadata for all APKs that were generated from a given app bundle. GeneratedapkMethods A builder providing access to all methods supported on generatedapk resources.
It is not used directly, but through the AndroidPublisher hub. GetOneTimeProductOfferRequest Request message for GetOneTimeProductOffers. GetSubscriptionOfferRequest Request message for GetSubscriptionOffer. Grant An access grant resource. GrantCreateCall Grant access for a user to the given package. GrantDeleteCall Removes all access for the user to the given package or developer account. GrantMethods A builder providing access to all methods supported on grant resources.
It is not used directly, but through the AndroidPublisher hub. GrantPatchCall Updates access for the user to the given package. Image An uploaded image. The resource for ImagesService. ImagesDeleteAllResponse Response for deleting all images. ImagesListResponse Response listing all images. ImagesUploadResponse Response for uploading an image. InAppProduct An in-app product. The resource for InappproductsService. InAppProductListing Store listing of a single in-app product. InappproductBatchDeleteCall Deletes in-app products (managed products or subscriptions). Set the latencyTolerance field on nested requests to PRODUCT_UPDATE_LATENCY_TOLERANCE_LATENCY_TOLERANT to achieve maximum update throughput. This method should not be used to delete subscriptions. See this article for more information. InappproductBatchGetCall Reads multiple in-app products, which can be managed products or subscriptions. This method should not be used to retrieve subscriptions. See this article for more information. InappproductBatchUpdateCall Updates or inserts one or more in-app products (managed products or subscriptions). Set the latencyTolerance field on nested requests to PRODUCT_UPDATE_LATENCY_TOLERANCE_LATENCY_TOLERANT to achieve maximum update throughput. This method should no longer be used to update subscriptions. See this article for more information. InappproductDeleteCall Deletes an in-app product (a managed product or a subscription). This method should no longer be used to delete subscriptions. See this article for more information. InappproductGetCall Gets an in-app product, which can be a managed product or a subscription. This method should no longer be used to retrieve subscriptions. See this article for more information. InappproductInsertCall Creates an in-app product (a managed product or a subscription). This method should no longer be used to create subscriptions. See this article for more information. InappproductListCall Lists all in-app products - both managed products and subscriptions. If an app has a large number of in-app products, the response may be paginated. In this case the response field tokenPagination.nextPageToken will be set and the caller should provide its value as a token request parameter to retrieve the next page. This method should no longer be used to retrieve subscriptions. See this article for more information. InappproductMethods A builder providing access to all methods supported on inappproduct resources.
It is not used directly, but through the AndroidPublisher hub. InappproductPatchCall Patches an in-app product (a managed product or a subscription). This method should no longer be used to update subscriptions. See this article for more information. InappproductUpdateCall Updates an in-app product (a managed product or a subscription). This method should no longer be used to update subscriptions. See this article for more information. InappproductsBatchDeleteRequest Request to delete multiple in-app products. InappproductsBatchGetResponse Response message for BatchGetSubscriptions endpoint. InappproductsBatchUpdateRequest Request to update or insert one or more in-app products. InappproductsBatchUpdateResponse Response for a batch in-app product update. InappproductsDeleteRequest Request to delete an in-app product. InappproductsListResponse Response listing all in-app products. InappproductsUpdateRequest Request to update an in-app product. InstallmentPlan Information to a installment plan. InstallmentsBasePlanType Represents an installments base plan where a user commits to a specified number of payments. InternalAppSharingArtifact An artifact resource which gets created when uploading an APK or Android App Bundle through internal app sharing. InternalappsharingartifactMethods A builder providing access to all methods supported on internalappsharingartifact resources.
It is not used directly, but through the AndroidPublisher hub. InternalappsharingartifactUploadapkCall Uploads an APK to internal app sharing. If you are using the Google API client libraries, please increase the timeout of the http request before calling this endpoint (a timeout of 2 minutes is recommended). See Timeouts and Errors for an example in java. InternalappsharingartifactUploadbundleCall Uploads an app bundle to internal app sharing. If you are using the Google API client libraries, please increase the timeout of the http request before calling this endpoint (a timeout of 2 minutes is recommended). See Timeouts and Errors for an example in java. IntroductoryPriceDetails Details of an introductory price pricing phase. IntroductoryPriceInfo Contains the introductory price information for a subscription. ItemReplacement Details about a subscription line item that is being replaced. LanguageTargeting Targeting based on language. LineItem Details of a line item. ListAppRecoveriesResponse Response message for ListAppRecoveries. – api-linter: core::0158::response-next-page-token-field=disabled ListDeviceTierConfigsResponse Response listing existing device tier configs. ListOneTimeProductOffersResponse Response message for ListOneTimeProductOffers. ListOneTimeProductsResponse Response message for ListOneTimeProducts. ListSubscriptionOffersResponse Response message for ListSubscriptionOffers. ListSubscriptionsResponse Response message for ListSubscriptions. ListUsersResponse A response containing one or more users with access to an account. Listing A localized store listing. The resource for ListingsService. ListingsListResponse Response listing all localized listings. LocalizedText Localized text in given language. ManagedProductTaxAndComplianceSettings Details about taxation and legal compliance for managed products. MigrateBasePlanPricesRequest Request message for MigrateBasePlanPrices. MigrateBasePlanPricesResponse Response message for MigrateBasePlanPrices. ModuleMetadata Metadata of a module. ModuleTargeting Targeting on the module level. MonetizationConvertRegionPriceCall Calculates the region prices, using today’s exchange rate and country-specific pricing patterns, based on the price in the request for a set of regions. MonetizationMethods A builder providing access to all methods supported on monetization resources.
It is not used directly, but through the AndroidPublisher hub. MonetizationOnetimeproductBatchDeleteCall Deletes one or more one-time products. MonetizationOnetimeproductBatchGetCall Reads one or more one-time products. MonetizationOnetimeproductBatchUpdateCall Creates or updates one or more one-time products. MonetizationOnetimeproductDeleteCall Deletes a one-time product. MonetizationOnetimeproductGetCall Reads a single one-time product. MonetizationOnetimeproductListCall Lists all one-time products under a given app. MonetizationOnetimeproductPatchCall Creates or updates a one-time product. MonetizationOnetimeproductPurchaseOptionBatchDeleteCall Deletes purchase options across one or multiple one-time products. By default this operation will fail if there are any existing offers under the deleted purchase options. Use the force parameter to override the default behavior. MonetizationOnetimeproductPurchaseOptionBatchUpdateStateCall Activates or deactivates purchase options across one or multiple one-time products. MonetizationOnetimeproductPurchaseOptionOfferActivateCall Activates a one-time product offer. MonetizationOnetimeproductPurchaseOptionOfferBatchDeleteCall Deletes one or more one-time product offers. MonetizationOnetimeproductPurchaseOptionOfferBatchGetCall Reads one or more one-time product offers. MonetizationOnetimeproductPurchaseOptionOfferBatchUpdateCall Creates or updates one or more one-time product offers. MonetizationOnetimeproductPurchaseOptionOfferBatchUpdateStateCall Updates a batch of one-time product offer states. MonetizationOnetimeproductPurchaseOptionOfferCancelCall Cancels a one-time product offer. MonetizationOnetimeproductPurchaseOptionOfferDeactivateCall Deactivates a one-time product offer. MonetizationOnetimeproductPurchaseOptionOfferListCall Lists all offers under a given app, product, or purchase option. MonetizationSubscriptionArchiveCall Deprecated: subscription archiving is not supported. MonetizationSubscriptionBasePlanActivateCall Activates a base plan. Once activated, base plans will be available to new subscribers. MonetizationSubscriptionBasePlanBatchMigratePriceCall Batch variant of the MigrateBasePlanPrices endpoint. Set the latencyTolerance field on nested requests to PRODUCT_UPDATE_LATENCY_TOLERANCE_LATENCY_TOLERANT to achieve maximum update throughput. MonetizationSubscriptionBasePlanBatchUpdateStateCall Activates or deactivates base plans across one or multiple subscriptions. Set the latencyTolerance field on nested requests to PRODUCT_UPDATE_LATENCY_TOLERANCE_LATENCY_TOLERANT to achieve maximum update throughput. MonetizationSubscriptionBasePlanDeactivateCall Deactivates a base plan. Once deactivated, the base plan will become unavailable to new subscribers, but existing subscribers will maintain their subscription MonetizationSubscriptionBasePlanDeleteCall Deletes a base plan. Can only be done for draft base plans. This action is irreversible. MonetizationSubscriptionBasePlanMigratePriceCall Migrates subscribers from one or more legacy price cohorts to the current price. Requests result in Google Play notifying affected subscribers. Only up to 250 simultaneous legacy price cohorts are supported. MonetizationSubscriptionBasePlanOfferActivateCall Activates a subscription offer. Once activated, subscription offers will be available to new subscribers. MonetizationSubscriptionBasePlanOfferBatchGetCall Reads one or more subscription offers. MonetizationSubscriptionBasePlanOfferBatchUpdateCall Updates a batch of subscription offers. Set the latencyTolerance field on nested requests to PRODUCT_UPDATE_LATENCY_TOLERANCE_LATENCY_TOLERANT to achieve maximum update throughput. MonetizationSubscriptionBasePlanOfferBatchUpdateStateCall Updates a batch of subscription offer states. Set the latencyTolerance field on nested requests to PRODUCT_UPDATE_LATENCY_TOLERANCE_LATENCY_TOLERANT to achieve maximum update throughput. MonetizationSubscriptionBasePlanOfferCreateCall Creates a new subscription offer. Only auto-renewing base plans can have subscription offers. The offer state will be DRAFT until it is activated. MonetizationSubscriptionBasePlanOfferDeactivateCall Deactivates a subscription offer. Once deactivated, existing subscribers will maintain their subscription, but the offer will become unavailable to new subscribers. MonetizationSubscriptionBasePlanOfferDeleteCall Deletes a subscription offer. Can only be done for draft offers. This action is irreversible. MonetizationSubscriptionBasePlanOfferGetCall Reads a single offer MonetizationSubscriptionBasePlanOfferListCall Lists all offers under a given subscription. MonetizationSubscriptionBasePlanOfferPatchCall Updates an existing subscription offer. MonetizationSubscriptionBatchGetCall Reads one or more subscriptions. MonetizationSubscriptionBatchUpdateCall Updates a batch of subscriptions. Set the latencyTolerance field on nested requests to PRODUCT_UPDATE_LATENCY_TOLERANCE_LATENCY_TOLERANT to achieve maximum update throughput. MonetizationSubscriptionCreateCall Creates a new subscription. Newly added base plans will remain in draft state until activated. MonetizationSubscriptionDeleteCall Deletes a subscription. A subscription can only be deleted if it has never had a base plan published. MonetizationSubscriptionGetCall Reads a single subscription. MonetizationSubscriptionListCall Lists all subscriptions under a given app. MonetizationSubscriptionPatchCall Updates an existing subscription. Money Represents an amount of money with its currency type. MultiAbi Represents a list of ABIs. MultiAbiTargeting Targeting based on multiple abis. OfferDetails Offer details information related to a purchase line item. OfferPhaseDetails Details of a pricing phase for the entitlement period funded by this order. OfferTag Represents a custom tag specified for a product offer. OneTimeCode A single use promotion code. OneTimeExternalTransaction Represents a one-time transaction. OneTimeProduct A single one-time product for an app. OneTimeProductBuyPurchaseOption A purchase option that can be bought. OneTimeProductDiscountedOffer Configuration specific to discounted offers. OneTimeProductListing Regional store listing for a one-time product. OneTimeProductOffer A single offer for a one-time product. OneTimeProductOfferNoPriceOverrideOptions Options for one-time product offers without a regional price override. OneTimeProductOfferRegionalPricingAndAvailabilityConfig Regional pricing and availability configuration for a one-time product offer. OneTimeProductPreOrderOffer Configuration specific to pre-order offers. OneTimeProductPurchaseOption A single purchase option for a one-time product. OneTimeProductPurchaseOptionNewRegionsConfig Pricing information for any new regions Play may launch in the future. OneTimeProductPurchaseOptionRegionalPricingAndAvailabilityConfig Regional pricing and availability configuration for a purchase option. OneTimeProductRentPurchaseOption A purchase option that can be rented. OneTimeProductTaxAndComplianceSettings Details about taxation, Google Play policy and legal compliance for one-time products. OneTimePurchaseDetails Details of a one-time purchase. Order The Order resource encapsulates comprehensive information about a transaction made on Google Play. It includes a variety of attributes that provide details about the order itself, the products purchased, and the history of events related to the order. The Orders APIs provide real-time access to your order data within the Google Play ecosystem. You can retrieve detailed information and metadata for both one-time and recurring orders, including transaction details like charges, taxes, and refunds, as well as metadata such as pricing phases for subscriptions. The Orders APIs let you automate tasks related to order management, reducing the need for manual checks via the Play Developer Console. The following are some of the use cases for this API: + Real-time order data retrieval - Get order details and metadata immediately after a purchase using an order ID. + Order update synchronization - Periodically sync order updates to maintain an up-to-date record of order information. Note: + The Orders API calls count towards your Play Developer API quota, which defaults to 200K daily, and may be insufficient to sync extensive order histories. + A maximum of 1000 orders can be retrieved per call. Using larger page sizes is recommended to minimize quota usage. Check your quota in the Cloud Console and request more if required. OrderBatchgetCall Get order details for a list of orders. OrderDetails Detailed information about the order at creation time. OrderGetCall Get order details for a single order. OrderHistory Details about events which modified the order. OrderMethods A builder providing access to all methods supported on order resources.
It is not used directly, but through the AndroidPublisher hub. OrderRefundCall Refunds a user’s subscription or in-app purchase order. Orders older than 3 years cannot be refunded. OtherRecurringProduct Details of a recurring external transaction product which doesn’t belong to any other more specific category. OtherRegionsBasePlanConfig Pricing information for any new locations Play may launch in. OtherRegionsSubscriptionOfferConfig Configuration for any new locations Play may launch in specified on a subscription offer. OtherRegionsSubscriptionOfferPhaseConfig Configuration for any new locations Play may launch in for a single offer phase. OtherRegionsSubscriptionOfferPhaseFreePriceOverride Represents the free price override configuration for any new locations Play may launch for a single offer phase. OtherRegionsSubscriptionOfferPhasePrices Pricing information for any new locations Play may launch in. OutOfAppPurchaseContext Information specific to an out of app purchase. PageInfo Information about the current page. List operations that supports paging return only one “page” of results. This protocol buffer message describes the page that has been returned. PaidAppDetails Details of a paid app purchase. PartialRefund A partial refund of a transaction. PartialRefundEvent Details of the partial refund events for this order. PausedStateContext Information specific to a subscription in paused state. PendingCancellation This is an indicator of whether there is a pending cancellation on the virtual installment plan. The cancellation will happen only after the user finished all committed payments. PointsDetails Details relating to any Play Points applied to an order. PreorderDetails Details of a pre-order purchase. PreorderOfferDetails Offer details information related to a preorder line item. PrepaidBasePlanType Represents a base plan that does not automatically renew at the end of the base plan, and must be manually renewed by the user. PrepaidPlan Information related to a prepaid plan. Price Definition of a price, i.e. currency and units. PriceStepUpConsentDetails Information related to a price step-up that requires user consent. ProcessedEvent Details of when the order was processed. ProductLineItem Contains item-level info for a ProductPurchaseV2. ProductOfferDetails Offer details information related to a purchase line item. ProductPurchase A ProductPurchase resource indicates the status of a user’s inapp product purchase. ProductPurchaseV2 A ProductPurchaseV2 resource indicates the status of a user’s inapp product purchase. ProductPurchasesAcknowledgeRequest Request for the product.purchases.acknowledge API. ProrationPeriodDetails Details of a proration period. A proration period can be a period calculated during a plan change to cover existing entitlements (For more information, see Allow users to upgrade, downgrade, or change their subscription , or a prorated period to align add-on renewal dates with the base (For more information, see Rules applicable for items in the purchase ). PurchaseMethods A builder providing access to all methods supported on purchase resources.
It is not used directly, but through the AndroidPublisher hub. PurchaseOptionTaxAndComplianceSettings Details about taxation, Google Play policy and legal compliance for one-time product purchase options. PurchaseProductAcknowledgeCall Acknowledges a purchase of an inapp item. PurchaseProductConsumeCall Consumes a purchase for an inapp item. PurchaseProductGetCall Checks the purchase and consumption status of an inapp item. PurchaseProductsv2Getproductpurchasev2Call Checks the purchase and consumption status of an inapp item. PurchaseStateContext Context about the purchase state. PurchaseSubscriptionAcknowledgeCall Acknowledges a subscription purchase. PurchaseSubscriptionCancelCall Cancels a user’s subscription purchase. The subscription remains valid until its expiration time. Newer version is available at purchases.subscriptionsv2.cancel for better client library support. PurchaseSubscriptionDeferCall Defers a user’s subscription purchase until a specified future expiration time. PurchaseSubscriptionGetCall Deprecated: Use purchases.subscriptionsv2.get instead. Checks whether a user’s subscription purchase is valid and returns its expiry time. PurchaseSubscriptionRefundCall Deprecated: Use orders.refund instead. Refunds a user’s subscription purchase, but the subscription remains valid until its expiration time and it will continue to recur. PurchaseSubscriptionRevokeCall Deprecated: Use purchases.subscriptionsv2.revoke instead. Refunds and immediately revokes a user’s subscription purchase. Access to the subscription will be terminated immediately and it will stop recurring. PurchaseSubscriptionsv2CancelCall Cancel a subscription purchase for the user. PurchaseSubscriptionsv2GetCall Get metadata about a subscription PurchaseSubscriptionsv2RevokeCall Revoke a subscription purchase for the user. PurchaseVoidedpurchaseListCall Lists the purchases that were canceled, refunded or charged-back. RecurringExternalTransaction Represents a transaction that is part of a recurring series of payments. This can be a subscription or a one-time product with multiple payments (such as preorder). RefundDetails Details for a partial or full refund. RefundEvent Details of when the order was fully refunded. RefundExternalTransactionRequest A request to refund an existing external transaction. RegionalBasePlanConfig Configuration for a base plan specific to a region. RegionalPriceMigrationConfig Configuration for migration of a legacy price cohort. RegionalSubscriptionOfferConfig Configuration for a subscription offer in a single region. RegionalSubscriptionOfferPhaseConfig Configuration for a single phase of a subscription offer in a single region. RegionalSubscriptionOfferPhaseFreePriceOverride Represents the free price override configuration for a single phase of a subscription offer RegionalTaxConfig Details about taxation in a given geographical region. RegionalTaxRateInfo Specified details about taxation in a given geographical region. Regions Region targeting data for app recovery action targeting. RegionsVersion The version of the available regions being used for the specified resource. RemoteInAppUpdate Object representation for Remote in-app update action type. RemoteInAppUpdateData Data related to Remote In-App Update action such as recovered user count, affected user count etc. RemoteInAppUpdateDataPerBundle Data related to the recovery action at bundle level. RentOfferDetails Offer details information related to a rental line item. RentalDetails Details of a rental purchase. ReplacementCancellation Information specific to cancellations caused by subscription replacement. RestrictedPaymentCountries Countries where the purchase of this product is restricted to payment methods registered in the same country. If empty, no payment location restrictions are imposed. Review An Android app review. ReviewGetCall Gets a single review. ReviewListCall Lists all reviews. ReviewMethods A builder providing access to all methods supported on review resources.
It is not used directly, but through the AndroidPublisher hub. ReviewReplyCall Replies to a single review, or updates an existing reply. ReviewReplyResult The result of replying/updating a reply to review. ReviewsListResponse Response listing reviews. ReviewsReplyRequest Request to reply to review or update existing reply. ReviewsReplyResponse Response on status of replying to a review. RevocationContext Revocation context of the purchases.subscriptionsv2.revoke API. RevocationContextFullRefund Used to determine if the refund type in the RevocationContext is a full refund. RevocationContextItemBasedRefund Used to determine what specific item to revoke in a subscription with multiple items. RevocationContextProratedRefund Used to determine if the refund type in the RevocationContext is a prorated refund. RevokeSubscriptionPurchaseRequest Request for the purchases.subscriptionsv2.revoke API. RevokeSubscriptionPurchaseResponse Response for the purchases.subscriptionsv2.revoke API. SafetyLabelsUpdateRequest Request to update Safety Labels of an app. SafetyLabelsUpdateResponse Response for SafetyLabelsUpdate rpc. ScreenDensity Represents a screen density. ScreenDensityTargeting Targeting based on screen density. SdkVersion Represents an sdk version. SdkVersionTargeting Targeting based on sdk version. SignupPromotion The promotion applied on this item when purchased. SplitApkMetadata Holds data specific to Split APKs. SplitApkVariant Variant is a group of APKs that covers a part of the device configuration space. APKs from multiple variants are never combined on one device. StandaloneApkMetadata Holds data specific to Standalone APKs. SubscribeWithGoogleInfo Information associated with purchases made with ‘Subscribe with Google’. Subscription A single subscription for an app. SubscriptionCancelSurveyResult Information provided by the user when they complete the subscription cancellation flow (cancellation reason survey). SubscriptionDeferralInfo A SubscriptionDeferralInfo contains the data needed to defer a subscription purchase to a future expiry time. SubscriptionDetails Details of a subscription purchase. SubscriptionItemPriceChangeDetails Price change related information of a subscription item. SubscriptionListing The consumer-visible metadata of a subscription. SubscriptionOffer A single, temporary offer SubscriptionOfferPhase A single phase of a subscription offer. SubscriptionOfferTargeting Defines the rule a user needs to satisfy to receive this offer. SubscriptionPriceChange Contains the price change information for a subscription that can be used to control the user journey for the price change in the app. This can be in the form of seeking confirmation from the user or tailoring the experience for a successful conversion. SubscriptionPurchase A SubscriptionPurchase resource indicates the status of a user’s subscription purchase. SubscriptionPurchaseLineItem Item-level info for a subscription purchase. SubscriptionPurchaseV2 Indicates the status of a user’s subscription purchase. SubscriptionPurchasesAcknowledgeRequest Request for the purchases.subscriptions.acknowledge API. SubscriptionPurchasesDeferRequest Request for the purchases.subscriptions.defer API. SubscriptionPurchasesDeferResponse Response for the purchases.subscriptions.defer API. SubscriptionTaxAndComplianceSettings Details about taxation, Google Play policy, and legal compliance for subscription products. SystemApkOptions Options for system APKs. SystemApksListResponse Response to list previously created system APK variants. SystemFeature Representation of a system feature. SystemInitiatedCancellation Information specific to cancellations initiated by Google system. SystemOnChip Representation of a System-on-Chip (SoC) of an Android device. Can be used to target S+ devices. SystemapkMethods A builder providing access to all methods supported on systemapk resources.
It is not used directly, but through the AndroidPublisher hub. SystemapkVariantCreateCall Creates an APK which is suitable for inclusion in a system image from an already uploaded Android App Bundle. SystemapkVariantDownloadCall Downloads a previously created system APK which is suitable for inclusion in a system image. SystemapkVariantGetCall Returns a previously created system APK variant. SystemapkVariantListCall Returns the list of previously created system APK variants. Targeting Targeting details for a recovery action such as regions, android sdk levels, app versions etc. TargetingInfo Targeting information about the generated apks. TargetingRuleScope Defines the scope of subscriptions which a targeting rule can match to target offers to users based on past or current entitlement. TargetingRuleScopeAnySubscriptionInApp Represents the targeting rule scope corresponding to any subscription in the parent app. TargetingRuleScopeThisSubscription Represents the targeting rule scope corresponding to the subscriptions in which this offer is defined. TargetingUpdate Update type for targeting. Note it is always a subset Targeting. TestPurchase Whether this subscription purchase is a test purchase. TestPurchaseContext Context about a test purchase. Testers The testers of an app. The resource for TestersService. Note: while it is possible in the Play Console UI to add testers via email lists, email lists are not supported by this resource. TextureCompressionFormat Represents texture compression format. TextureCompressionFormatTargeting Targeting by a texture compression format. Timestamp A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970. TokenPagination Pagination information returned by a List operation when token pagination is enabled. List operations that supports paging return only one “page” of results. This protocol buffer message describes the page that has been returned. When using token pagination, clients should use the next/previous token to get another page of the result. The presence or absence of next/previous token indicates whether a next/previous page is available and provides a mean of accessing this page. ListRequest.page_token should be set to either next_page_token or previous_page_token to access another page. Track A track configuration. The resource for TracksService. TrackConfig Configurations of the new track. TrackCountryAvailability Resource for per-track country availability information. TrackRelease A release within a track. TrackTargetedCountry Representation of a single country where the contents of a track are available. TracksListResponse Response listing all tracks. UpdateBasePlanStateRequest Request message to update the state of a subscription base plan. UpdateOneTimeProductOfferRequest Request message for UpdateOneTimeProductOffer. UpdateOneTimeProductOfferStateRequest Request message to update the state of a one-time product offer. UpdateOneTimeProductRequest Request message for UpdateOneTimeProduct. UpdatePurchaseOptionStateRequest Request message to update the state of a one-time product purchase option. UpdateSubscriptionOfferRequest Request message for UpdateSubscriptionOffer. UpdateSubscriptionOfferStateRequest Request message to update the state of a subscription offer. UpdateSubscriptionRequest Request message for UpdateSubscription. UpgradeTargetingRule Represents a targeting rule of the form: User currently has {scope} [with billing period {billing_period}]. User A user resource. UserComment User entry from conversation between user and developer. UserCountriesTargeting Describes an inclusive/exclusive list of country codes that module targets. UserCountrySet A set of user countries. A country set determines what variation of app content gets served to a specific location. UserCreateCall Grant access for a user to the given developer account. UserDeleteCall Removes all access for the user to the given developer account. UserInitiatedCancellation Information specific to cancellations initiated by users. UserListCall Lists all users with access to a developer account. UserMethods A builder providing access to all methods supported on user resources.
It is not used directly, but through the AndroidPublisher hub. UserPatchCall Updates access for the user to the developer account. UsesPermission A permission used by this APK. VanityCode A multiple use, predefined promotion code. Variant APK that is suitable for inclusion in a system image. The resource of SystemApksService. VariantTargeting Targeting on the level of variants. VoidedPurchase A VoidedPurchase resource indicates a purchase that was either canceled/refunded/charged-back. VoidedPurchasesListResponse Response for the voidedpurchases.list API. Scope Identifies the an OAuth2 authorization scope.
A scope is needed when requesting an
authorization token .