pub struct AbiTargeting {
pub alternatives: Option<Vec<Abi>>,
pub value: Option<Vec<Abi>>,
}Expand description
Targeting based on Abi.
This type is not used in any activity, and only used as part of another schema.
Fields
alternatives: Option<Vec<Abi>>Targeting of other sibling directories that were in the Bundle. For main splits this is targeting of other main splits.
value: Option<Vec<Abi>>Value of an abi.