pub struct ActivateBasePlanRequest {
pub base_plan_id: Option<String>,
pub latency_tolerance: Option<String>,
pub package_name: Option<String>,
pub product_id: Option<String>,
}Expand description
Request message for ActivateBasePlan.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
base_plan_id: Option<String>Required. The unique base plan ID of the base plan to activate.
latency_tolerance: Option<String>Optional. The latency tolerance for the propagation of this product update. Defaults to latency-sensitive.
package_name: Option<String>Required. The parent app (package name) of the base plan to activate.
product_id: Option<String>Required. The parent subscription (ID) of the base plan to activate.