pub struct ActivateOneTimeProductOfferRequest {
pub latency_tolerance: Option<String>,
pub offer_id: Option<String>,
pub package_name: Option<String>,
pub product_id: Option<String>,
pub purchase_option_id: Option<String>,
}Expand description
Request message for ActivateOneTimeProductOffer.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
latency_tolerance: Option<String>Optional. The latency tolerance for the propagation of this update. Defaults to latency-sensitive.
offer_id: Option<String>Required. The offer ID of the offer to activate.
package_name: Option<String>Required. The parent app (package name) of the offer to activate.
product_id: Option<String>Required. The parent one-time product (ID) of the offer to activate.
purchase_option_id: Option<String>Required. The parent purchase option (ID) of the offer to activate.