pub struct AddTargetingRequest {
pub targeting_update: Option<TargetingUpdate>,
}Expand description
Request message for AddTargeting.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- add targeting apprecovery (request)
Fields
targeting_update: Option<TargetingUpdate>Specifies targeting updates such as regions, android sdk versions etc.