pub struct AllUsers {
pub is_all_users_requested: Option<bool>,
}Expand description
Object representation to describe all set of users.
This type is not used in any activity, and only used as part of another schema.
Fields
is_all_users_requested: Option<bool>Required. Set to true if all set of users are needed.