pub struct ApkDescription {
pub asset_slice_metadata: Option<SplitApkMetadata>,
pub instant_apk_metadata: Option<SplitApkMetadata>,
pub path: Option<String>,
pub split_apk_metadata: Option<SplitApkMetadata>,
pub standalone_apk_metadata: Option<StandaloneApkMetadata>,
pub targeting: Option<ApkTargeting>,
}Expand description
Description of the created apks.
This type is not used in any activity, and only used as part of another schema.
Fields
asset_slice_metadata: Option<SplitApkMetadata>Set only for asset slices.
instant_apk_metadata: Option<SplitApkMetadata>Set only for Instant split APKs.
path: Option<String>Path of the Apk, will be in the following format: .apk where DownloadId is the ID used to download the apk using GeneratedApks.Download API.
split_apk_metadata: Option<SplitApkMetadata>Set only for Split APKs.
standalone_apk_metadata: Option<StandaloneApkMetadata>Set only for standalone APKs.
targeting: Option<ApkTargeting>Apk-level targeting.