pub struct AppVersionRange {
pub version_code_end: Option<i64>,
pub version_code_start: Option<i64>,
}Expand description
Data format for a continuous range of app versions.
This type is not used in any activity, and only used as part of another schema.
Fields
version_code_end: Option<i64>Highest app version in the range, inclusive.
version_code_start: Option<i64>Lowest app version in the range, inclusive.