pub struct ApprecoveryMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on apprecovery resources.
It is not used directly, but through the AndroidPublisher hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_androidpublisher3 as androidpublisher3;
use androidpublisher3::{AndroidPublisher, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = AndroidPublisher::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `add_targeting(...)`, `cancel(...)`, `create(...)`, `deploy(...)` and `list(...)`
// to build up your call.
let rb = hub.apprecovery();Implementations
Sourceimpl<'a, C> ApprecoveryMethods<'a, C>
impl<'a, C> ApprecoveryMethods<'a, C>
Sourcepub fn add_targeting(
&self,
request: AddTargetingRequest,
package_name: &str,
app_recovery_id: i64,
) -> ApprecoveryAddTargetingCall<'a, C>
pub fn add_targeting( &self, request: AddTargetingRequest, package_name: &str, app_recovery_id: i64, ) -> ApprecoveryAddTargetingCall<'a, C>
Create a builder to help you perform the following task:
Incrementally update targeting for a recovery action. Note that only the criteria selected during the creation of recovery action can be expanded.
Arguments
request- No description provided.packageName- Required. Package name of the app for which recovery action is to be updated.appRecoveryId- Required. ID corresponding to the app recovery action.
Sourcepub fn cancel(
&self,
request: CancelAppRecoveryRequest,
package_name: &str,
app_recovery_id: i64,
) -> ApprecoveryCancelCall<'a, C>
pub fn cancel( &self, request: CancelAppRecoveryRequest, package_name: &str, app_recovery_id: i64, ) -> ApprecoveryCancelCall<'a, C>
Create a builder to help you perform the following task:
Cancel an already executing app recovery action. Note that this action changes status of the recovery action to CANCELED.
Arguments
request- No description provided.packageName- Required. Package name of the app for which recovery action cancellation is requested.appRecoveryId- Required. ID corresponding to the app recovery action.
Sourcepub fn create(
&self,
request: CreateDraftAppRecoveryRequest,
package_name: &str,
) -> ApprecoveryCreateCall<'a, C>
pub fn create( &self, request: CreateDraftAppRecoveryRequest, package_name: &str, ) -> ApprecoveryCreateCall<'a, C>
Create a builder to help you perform the following task:
Create an app recovery action with recovery status as DRAFT. Note that this action does not execute the recovery action.
Arguments
request- No description provided.packageName- Required. Package name of the app on which recovery action is performed.
Sourcepub fn deploy(
&self,
request: DeployAppRecoveryRequest,
package_name: &str,
app_recovery_id: i64,
) -> ApprecoveryDeployCall<'a, C>
pub fn deploy( &self, request: DeployAppRecoveryRequest, package_name: &str, app_recovery_id: i64, ) -> ApprecoveryDeployCall<'a, C>
Create a builder to help you perform the following task:
Deploy an already created app recovery action with recovery status DRAFT. Note that this action activates the recovery action for all targeted users and changes its status to ACTIVE.
Arguments
request- No description provided.packageName- Required. Package name of the app for which recovery action is deployed.appRecoveryId- Required. ID corresponding to the app recovery action to deploy.
Sourcepub fn list(&self, package_name: &str) -> ApprecoveryListCall<'a, C>
pub fn list(&self, package_name: &str) -> ApprecoveryListCall<'a, C>
Create a builder to help you perform the following task:
List all app recovery action resources associated with a particular package name and app version.
Arguments
packageName- Required. Package name of the app for which list of recovery actions is requested.