pub struct BatchGetOneTimeProductsResponse {
pub one_time_products: Option<Vec<OneTimeProduct>>,
}Expand description
Response message for the BatchGetOneTimeProducts endpoint.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- onetimeproducts batch get monetization (response)
Fields
one_time_products: Option<Vec<OneTimeProduct>>The list of requested one-time products, in the same order as the request.