pub struct BatchUpdateOneTimeProductOfferStatesRequest {
pub requests: Option<Vec<UpdateOneTimeProductOfferStateRequest>>,
}Expand description
Request message for BatchUpdateOneTimeProductOfferStates.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
requests: Option<Vec<UpdateOneTimeProductOfferStateRequest>>Required. The update request list of up to 100 elements. All requests must update different offers.