pub struct BatchUpdateOneTimeProductOffersResponse {
pub one_time_product_offers: Option<Vec<OneTimeProductOffer>>,
}Expand description
Response message for BatchUpdateOneTimeProductOffers.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
one_time_product_offers: Option<Vec<OneTimeProductOffer>>The list of updated one-time product offers, in the same order as the request.