pub struct BatchUpdateOneTimeProductsRequest {
pub requests: Option<Vec<UpdateOneTimeProductRequest>>,
}Expand description
Request message for BatchUpdateOneTimeProduct.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
requests: Option<Vec<UpdateOneTimeProductRequest>>Required. A list of update requests of up to 100 elements. All requests must update different one-time products.