pub struct BatchUpdatePurchaseOptionStatesResponse {
pub one_time_products: Option<Vec<OneTimeProduct>>,
}Expand description
Response message for BatchUpdatePurchaseOptionStates.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
one_time_products: Option<Vec<OneTimeProduct>>The list of updated one-time products. This list will match the requests one to one, in the same order.