pub struct BatchUpdateSubscriptionOfferStatesResponse {
pub subscription_offers: Option<Vec<SubscriptionOffer>>,
}Expand description
Response message for BatchUpdateSubscriptionOfferStates.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
subscription_offers: Option<Vec<SubscriptionOffer>>The updated subscription offers list.