pub struct CancelAppRecoveryRequest { /* private fields */ }Expand description
Request message for CancelAppRecovery.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- cancel apprecovery (request)