CancelSurveyResult

Struct CancelSurveyResult 

pub struct CancelSurveyResult {
    pub reason: Option<String>,
    pub reason_user_input: Option<String>,
}
Result of the cancel survey when the subscription was canceled by the user.

This type is not used in any activity, and only used as part of another schema.

Fields

reason: Option<String>

The reason the user selected in the cancel survey.

reason_user_input: Option<String>

Only set for CANCEL_SURVEY_REASON_OTHERS. This is the user’s freeform response to the survey.