pub struct CanceledStateContext {
pub developer_initiated_cancellation: Option<DeveloperInitiatedCancellation>,
pub replacement_cancellation: Option<ReplacementCancellation>,
pub system_initiated_cancellation: Option<SystemInitiatedCancellation>,
pub user_initiated_cancellation: Option<UserInitiatedCancellation>,
}Expand description
Information specific to a subscription in the SUBSCRIPTION_STATE_CANCELED or SUBSCRIPTION_STATE_EXPIRED state.
This type is not used in any activity, and only used as part of another schema.
Fields
developer_initiated_cancellation: Option<DeveloperInitiatedCancellation>Subscription was canceled by the developer.
replacement_cancellation: Option<ReplacementCancellation>Subscription was replaced by a new subscription.
system_initiated_cancellation: Option<SystemInitiatedCancellation>Subscription was canceled by the system, for example because of a billing problem.
user_initiated_cancellation: Option<UserInitiatedCancellation>Subscription was canceled by user.