CreateDraftAppRecoveryRequest

Struct CreateDraftAppRecoveryRequest 

pub struct CreateDraftAppRecoveryRequest {
    pub remote_in_app_update: Option<RemoteInAppUpdate>,
    pub targeting: Option<Targeting>,
}
Request message for CreateDraftAppRecovery.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

remote_in_app_update: Option<RemoteInAppUpdate>

Action type is remote in-app update. As a consequence of this action, a downloadable recovery module is also created for testing purposes.

targeting: Option<Targeting>

Specifies targeting criteria for the recovery action such as regions, android sdk versions, app versions etc.