pub struct DeactivatePurchaseOptionRequest {
pub latency_tolerance: Option<String>,
pub package_name: Option<String>,
pub product_id: Option<String>,
pub purchase_option_id: Option<String>,
}Expand description
Request message for UpdatePurchaseOptionState.
This type is not used in any activity, and only used as part of another schema.
Fields
latency_tolerance: Option<String>Optional. The latency tolerance for the propagation of this product update. Defaults to latency-sensitive.
package_name: Option<String>Required. The parent app (package name) of the purchase option to deactivate.
product_id: Option<String>Required. The parent one-time product (ID) of the purchase option to deactivate.
purchase_option_id: Option<String>Required. The purchase option ID of the purchase option to deactivate.