pub struct DeleteOneTimeProductOfferRequest {
pub latency_tolerance: Option<String>,
pub offer_id: Option<String>,
pub package_name: Option<String>,
pub product_id: Option<String>,
pub purchase_option_id: Option<String>,
}Expand description
Request message for deleting an one-time product offer.
This type is not used in any activity, and only used as part of another schema.
Fields
latency_tolerance: Option<String>Optional. The latency tolerance for the propagation of this product update. Defaults to latency-sensitive.
offer_id: Option<String>Required. The unique offer ID of the offer to delete.
package_name: Option<String>Required. The parent app (package name) of the offer to delete.
product_id: Option<String>Required. The parent one-time product (ID) of the offer to delete.
purchase_option_id: Option<String>Required. The parent purchase option (ID) of the offer to delete.