pub struct DeobfuscationFilesUploadResponse {
pub deobfuscation_file: Option<DeobfuscationFile>,
}Expand description
Responses for the upload.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- deobfuscationfiles upload edits (response)
Fields
deobfuscation_file: Option<DeobfuscationFile>The uploaded Deobfuscation File configuration.