pub struct DeviceSpec {
pub screen_density: Option<u32>,
pub supported_abis: Option<Vec<String>>,
pub supported_locales: Option<Vec<String>>,
}Expand description
The device spec used to generate a system APK.
This type is not used in any activity, and only used as part of another schema.
Fields
screen_density: Option<u32>Screen dpi.
supported_abis: Option<Vec<String>>Supported ABI architectures in the order of preference. The values should be the string as reported by the platform, e.g. “armeabi-v7a”, “x86_64”.
supported_locales: Option<Vec<String>>All installed locales represented as BCP-47 strings, e.g. “en-US”.