pub struct ExternalAccountIds {
pub obfuscated_account_id: Option<String>,
pub obfuscated_profile_id: Option<String>,
}Expand description
User account identifier in your app.
This type is not used in any activity, and only used as part of another schema.
Fields
obfuscated_account_id: Option<String>Optional. Specifies an optional obfuscated string that is uniquely associated with the purchaser’s user account in your app. If you pass this value, Google Play can use it to detect irregular activity. Do not use this field to store any Personally Identifiable Information (PII) such as emails in cleartext. Attempting to store PII in this field will result in purchases being blocked. Google Play recommends that you use either encryption or a one-way hash to generate an obfuscated identifier to send to Google Play. This identifier is limited to 64 characters. This field can only be set for resubscription purchases. See https://developer.android.com/reference/com/android/billingclient/api/BillingFlowParams.Builder#setobfuscatedaccountid to set this field for purchases made using the standard in-app billing flow.
obfuscated_profile_id: Option<String>Optional. Specifies an optional obfuscated string that is uniquely associated with the purchaser’s user profile in your app. If you pass this value, Google Play can use it to detect irregular activity. Do not use this field to store any Personally Identifiable Information (PII) such as emails in cleartext. Attempting to store PII in this field will result in purchases being blocked. Google Play recommends that you use either encryption or a one-way hash to generate an obfuscated identifier to send to Google Play. This identifier is limited to 64 characters. This field can only be set for resubscription purchases. See https://developer.android.com/reference/com/android/billingclient/api/BillingFlowParams.Builder#setobfuscatedprofileid to set this field for purchases made using the standard in-app billing flow.