pub struct FullRefund { /* private fields */ }Expand description
A full refund of the remaining amount of a transaction.
This type is not used in any activity, and only used as part of another schema.