pub struct GeneratedApksPerSigningKey {
pub certificate_sha256_hash: Option<String>,
pub generated_asset_pack_slices: Option<Vec<GeneratedAssetPackSlice>>,
pub generated_recovery_modules: Option<Vec<GeneratedRecoveryApk>>,
pub generated_split_apks: Option<Vec<GeneratedSplitApk>>,
pub generated_standalone_apks: Option<Vec<GeneratedStandaloneApk>>,
pub generated_universal_apk: Option<GeneratedUniversalApk>,
pub targeting_info: Option<TargetingInfo>,
}Expand description
Download metadata for split, standalone and universal APKs, as well as asset pack slices, signed with a given key.
This type is not used in any activity, and only used as part of another schema.
Fields
certificate_sha256_hash: Option<String>SHA256 hash of the APK signing public key certificate.
generated_asset_pack_slices: Option<Vec<GeneratedAssetPackSlice>>List of asset pack slices which will be served for this app bundle, signed with a key corresponding to certificate_sha256_hash.
generated_recovery_modules: Option<Vec<GeneratedRecoveryApk>>Generated recovery apks for recovery actions signed with a key corresponding to certificate_sha256_hash. This includes all generated recovery APKs, also those in draft or cancelled state. This field is not set if no recovery actions were created for this signing key.
generated_split_apks: Option<Vec<GeneratedSplitApk>>List of generated split APKs, signed with a key corresponding to certificate_sha256_hash.
generated_standalone_apks: Option<Vec<GeneratedStandaloneApk>>List of generated standalone APKs, signed with a key corresponding to certificate_sha256_hash.
generated_universal_apk: Option<GeneratedUniversalApk>Generated universal APK, signed with a key corresponding to certificate_sha256_hash. This field is not set if no universal APK was generated for this signing key.
targeting_info: Option<TargetingInfo>Contains targeting information about the generated apks.