pub struct GeneratedAssetPackSlice {
pub download_id: Option<String>,
pub module_name: Option<String>,
pub slice_id: Option<String>,
pub version: Option<i64>,
}Expand description
Download metadata for an asset pack slice.
This type is not used in any activity, and only used as part of another schema.
Fields
download_id: Option<String>Download ID, which uniquely identifies the APK to download. Should be supplied to generatedapks.download method.
module_name: Option<String>Name of the module that this asset slice belongs to.
slice_id: Option<String>Asset slice ID.
version: Option<i64>Asset module version.