pub struct GeneratedSplitApk {
pub download_id: Option<String>,
pub module_name: Option<String>,
pub split_id: Option<String>,
pub variant_id: Option<i32>,
}Expand description
Download metadata for a split APK.
This type is not used in any activity, and only used as part of another schema.
Fields
download_id: Option<String>Download ID, which uniquely identifies the APK to download. Should be supplied to generatedapks.download method.
module_name: Option<String>Name of the module that this APK belongs to.
split_id: Option<String>Split ID. Empty for the main split of the base module.
variant_id: Option<i32>ID of the generated variant.