pub struct InappproductsBatchDeleteRequest {
pub requests: Option<Vec<InappproductsDeleteRequest>>,
}Expand description
Request to delete multiple in-app products.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- batch delete inappproducts (request)
Fields
requests: Option<Vec<InappproductsDeleteRequest>>Individual delete requests. At least one request is required. Can contain up to 100 requests. All requests must correspond to different in-app products.