pub struct InappproductsBatchGetResponse {
pub inappproduct: Option<Vec<InAppProduct>>,
}Expand description
Response message for BatchGetSubscriptions endpoint.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- batch get inappproducts (response)
Fields
inappproduct: Option<Vec<InAppProduct>>The list of requested in-app products, in the same order as the request.