pub struct InappproductsDeleteRequest {
pub latency_tolerance: Option<String>,
pub package_name: Option<String>,
pub sku: Option<String>,
}Expand description
Request to delete an in-app product.
This type is not used in any activity, and only used as part of another schema.
Fields
latency_tolerance: Option<String>Optional. The latency tolerance for the propagation of this product update. Defaults to latency-sensitive.
package_name: Option<String>Package name of the app.
sku: Option<String>Unique identifier for the in-app product.