pub struct InappproductsUpdateRequest {
pub allow_missing: Option<bool>,
pub auto_convert_missing_prices: Option<bool>,
pub inappproduct: Option<InAppProduct>,
pub latency_tolerance: Option<String>,
pub package_name: Option<String>,
pub sku: Option<String>,
}Expand description
Request to update an in-app product.
This type is not used in any activity, and only used as part of another schema.
Fields
allow_missing: Option<bool>If set to true, and the in-app product with the given package_name and sku doesn’t exist, the in-app product will be created.
auto_convert_missing_prices: Option<bool>If true the prices for all regions targeted by the parent app that don’t have a price specified for this in-app product will be auto converted to the target currency based on the default price. Defaults to false.
inappproduct: Option<InAppProduct>The new in-app product.
latency_tolerance: Option<String>Optional. The latency tolerance for the propagation of this product update. Defaults to latency-sensitive.
package_name: Option<String>Package name of the app.
sku: Option<String>Unique identifier for the in-app product.