pub struct InstallmentPlan {
pub initial_committed_payments_count: Option<i32>,
pub pending_cancellation: Option<PendingCancellation>,
pub remaining_committed_payments_count: Option<i32>,
pub subsequent_committed_payments_count: Option<i32>,
}Expand description
Information to a installment plan.
This type is not used in any activity, and only used as part of another schema.
Fields
initial_committed_payments_count: Option<i32>Total number of payments the user is initially committed for.
pending_cancellation: Option<PendingCancellation>If present, this installment plan is pending to be canceled. The cancellation will happen only after the user finished all committed payments.
remaining_committed_payments_count: Option<i32>Total number of committed payments remaining to be paid for in this renewal cycle.
subsequent_committed_payments_count: Option<i32>Total number of payments the user will be committed for after each commitment period. Empty means the installment plan will fall back to a normal auto-renew subscription after initial commitment.