pub struct ListAppRecoveriesResponse {
pub recovery_actions: Option<Vec<AppRecoveryAction>>,
}Expand description
Response message for ListAppRecoveries. – api-linter: core::0158::response-next-page-token-field=disabled
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list apprecovery (response)
Fields
recovery_actions: Option<Vec<AppRecoveryAction>>List of recovery actions associated with the requested package name.