pub struct ListingsListResponse {
pub kind: Option<String>,
pub listings: Option<Vec<Listing>>,
}Expand description
Response listing all localized listings.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- listings list edits (response)
Fields
kind: Option<String>The kind of this response (“androidpublisher#listingsListResponse”).
listings: Option<Vec<Listing>>All localized listings.