pub struct ModuleMetadata {
pub delivery_type: Option<String>,
pub dependencies: Option<Vec<String>>,
pub module_type: Option<String>,
pub name: Option<String>,
pub targeting: Option<ModuleTargeting>,
}Expand description
Metadata of a module.
This type is not used in any activity, and only used as part of another schema.
Fields
delivery_type: Option<String>Indicates the delivery type (e.g. on-demand) of the module.
dependencies: Option<Vec<String>>Names of the modules that this module directly depends on. Each module implicitly depends on the base module.
module_type: Option<String>Indicates the type of this feature module.
name: Option<String>Module name.
targeting: Option<ModuleTargeting>The targeting that makes a conditional module installed. Relevant only for Split APKs.