pub struct MultiAbiTargeting {
pub alternatives: Option<Vec<MultiAbi>>,
pub value: Option<Vec<MultiAbi>>,
}Expand description
Targeting based on multiple abis.
This type is not used in any activity, and only used as part of another schema.
Fields
alternatives: Option<Vec<MultiAbi>>Targeting of other sibling directories that were in the Bundle. For main splits this is targeting of other main splits.
value: Option<Vec<MultiAbi>>Value of a multi abi.