pub struct OfferDetails {
pub base_plan_id: Option<String>,
pub offer_id: Option<String>,
pub offer_tags: Option<Vec<String>>,
}Expand description
Offer details information related to a purchase line item.
This type is not used in any activity, and only used as part of another schema.
Fields
base_plan_id: Option<String>The base plan ID. Present for all base plan and offers.
offer_id: Option<String>The offer ID. Only present for discounted offers.
The latest offer tags associated with the offer. It includes tags inherited from the base plan.