OneTimeProduct

Struct OneTimeProduct 

pub struct OneTimeProduct {
    pub listings: Option<Vec<OneTimeProductListing>>,
    pub offer_tags: Option<Vec<OfferTag>>,
    pub package_name: Option<String>,
    pub product_id: Option<String>,
    pub purchase_options: Option<Vec<OneTimeProductPurchaseOption>>,
    pub regions_version: Option<RegionsVersion>,
    pub restricted_payment_countries: Option<RestrictedPaymentCountries>,
    pub tax_and_compliance_settings: Option<OneTimeProductTaxAndComplianceSettings>,
}
A single one-time product for an app.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

listings: Option<Vec<OneTimeProductListing>>

Required. Set of localized title and description data. Must not have duplicate entries with the same language_code.

offer_tags: Option<Vec<OfferTag>>

Optional. List of up to 20 custom tags specified for this one-time product, and returned to the app through the billing library. Purchase options and offers for this product will also receive these tags in the billing library.

package_name: Option<String>

Required. Immutable. Package name of the parent app.

product_id: Option<String>

Required. Immutable. Unique product ID of the product. Unique within the parent app. Product IDs must start with a number or lowercase letter, and can contain numbers (0-9), lowercase letters (a-z), underscores (_), and periods (.).

purchase_options: Option<Vec<OneTimeProductPurchaseOption>>

Required. The set of purchase options for this one-time product.

regions_version: Option<RegionsVersion>

Output only. The version of the regions configuration that was used to generate the one-time product.

restricted_payment_countries: Option<RestrictedPaymentCountries>

Optional. Countries where the purchase of this one-time product is restricted to payment methods registered in the same country. If empty, no payment location restrictions are imposed.

tax_and_compliance_settings: Option<OneTimeProductTaxAndComplianceSettings>

Details about taxes and legal compliance.