pub struct OneTimeProductBuyPurchaseOption {
pub legacy_compatible: Option<bool>,
pub multi_quantity_enabled: Option<bool>,
}Expand description
A purchase option that can be bought.
This type is not used in any activity, and only used as part of another schema.
Fields
legacy_compatible: Option<bool>Optional. Whether this purchase option will be available in legacy PBL flows that do not support one-time products model. Up to one “buy” purchase option can be marked as backwards compatible.
multi_quantity_enabled: Option<bool>Optional. Whether this purchase option allows multi-quantity. Multi-quantity allows buyer to purchase more than one item in a single checkout.