pub struct OneTimeProductDiscountedOffer {
pub end_time: Option<DateTime<Utc>>,
pub redemption_limit: Option<i64>,
pub start_time: Option<DateTime<Utc>>,
}Expand description
Configuration specific to discounted offers.
This type is not used in any activity, and only used as part of another schema.
Fields
end_time: Option<DateTime<Utc>>Time when the offer will stop being available.
redemption_limit: Option<i64>Optional. The number of times this offer can be redeemed. If unset or set to 0, allows for unlimited offer redemptions. Otherwise must be a number between 1 and 50 inclusive.
start_time: Option<DateTime<Utc>>Time when the offer will start being available.