pub struct OneTimeProductListing {
pub description: Option<String>,
pub language_code: Option<String>,
pub title: Option<String>,
}Expand description
Regional store listing for a one-time product.
This type is not used in any activity, and only used as part of another schema.
Fields
description: Option<String>Required. The description of this product in the language of this listing. The maximum length is 200 characters.
language_code: Option<String>Required. The language of this listing, as defined by BCP-47, e.g., “en-US”.
title: Option<String>Required. The title of this product in the language of this listing. The maximum length is 55 characters.