OneTimeProductOffer

Struct OneTimeProductOffer 

pub struct OneTimeProductOffer {
    pub discounted_offer: Option<OneTimeProductDiscountedOffer>,
    pub offer_id: Option<String>,
    pub offer_tags: Option<Vec<OfferTag>>,
    pub package_name: Option<String>,
    pub pre_order_offer: Option<OneTimeProductPreOrderOffer>,
    pub product_id: Option<String>,
    pub purchase_option_id: Option<String>,
    pub regional_pricing_and_availability_configs: Option<Vec<OneTimeProductOfferRegionalPricingAndAvailabilityConfig>>,
    pub regions_version: Option<RegionsVersion>,
    pub state: Option<String>,
}
A single offer for a one-time product.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

discounted_offer: Option<OneTimeProductDiscountedOffer>

A discounted offer.

offer_id: Option<String>

Required. Immutable. The ID of this product offer. Must be unique within the purchase option. It must start with a number or lower-case letter, and can only contain lower-case letters (a-z), numbers (0-9), and hyphens (-). The maximum length is 63 characters.

offer_tags: Option<Vec<OfferTag>>

Optional. List of up to 20 custom tags specified for this offer, and returned to the app through the billing library.

package_name: Option<String>

Required. Immutable. The package name of the app the parent product belongs to.

pre_order_offer: Option<OneTimeProductPreOrderOffer>

A pre-order offer.

product_id: Option<String>

Required. Immutable. The ID of the parent product this offer belongs to.

purchase_option_id: Option<String>

Required. Immutable. The ID of the purchase option to which this offer is an extension.

regional_pricing_and_availability_configs: Option<Vec<OneTimeProductOfferRegionalPricingAndAvailabilityConfig>>

Set of regional pricing and availability information for this offer. Must not have duplicate entries with the same region_code.

regions_version: Option<RegionsVersion>

Output only. The version of the regions configuration that was used to generate the one-time product offer.

state: Option<String>

Output only. The current state of this offer. This field cannot be changed by updating the resource. Use the dedicated endpoints instead.