OneTimeProductOfferRegionalPricingAndAvailabilityConfig

Struct OneTimeProductOfferRegionalPricingAndAvailabilityConfig 

pub struct OneTimeProductOfferRegionalPricingAndAvailabilityConfig {
    pub absolute_discount: Option<Money>,
    pub availability: Option<String>,
    pub no_override: Option<OneTimeProductOfferNoPriceOverrideOptions>,
    pub region_code: Option<String>,
    pub relative_discount: Option<f64>,
}
Regional pricing and availability configuration for a one-time product offer.

This type is not used in any activity, and only used as part of another schema.

Fields

absolute_discount: Option<Money>

The absolute value of the discount that is subtracted from the purchase option price. It should be between 0 and the purchase option price.

availability: Option<String>

Required. The availability for this region.

no_override: Option<OneTimeProductOfferNoPriceOverrideOptions>

The price defined in the purchase option for this region will be used.

region_code: Option<String>

Required. Region code this configuration applies to, as defined by ISO 3166-2, e.g., “US”.

relative_discount: Option<f64>

The fraction of the purchase option price that the user pays for this offer. For example, if the purchase option price for this region is $12, then a 50% discount would correspond to a price of $6. The discount must be specified as a fraction strictly larger than 0 and strictly smaller than 1. The resulting price will be rounded to the nearest billable unit (e.g. cents for USD). The relative discount is considered invalid if the discounted price ends up being smaller than the minimum price allowed in this region.