pub struct OneTimeProductPreOrderOffer {
pub end_time: Option<DateTime<Utc>>,
pub price_change_behavior: Option<String>,
pub release_time: Option<DateTime<Utc>>,
pub start_time: Option<DateTime<Utc>>,
}Expand description
Configuration specific to pre-order offers.
This type is not used in any activity, and only used as part of another schema.
Fields
end_time: Option<DateTime<Utc>>Required. Time when the pre-order will stop being available.
price_change_behavior: Option<String>Required. Immutable. Specifies how price changes affect pre-existing pre-orders.
release_time: Option<DateTime<Utc>>Required. Time on which the product associated with the pre-order will be released and the pre-order orders fulfilled.
start_time: Option<DateTime<Utc>>Required. Time when the pre-order will start being available.