OneTimeProductPurchaseOptionNewRegionsConfig

Struct OneTimeProductPurchaseOptionNewRegionsConfig 

pub struct OneTimeProductPurchaseOptionNewRegionsConfig {
    pub availability: Option<String>,
    pub eur_price: Option<Money>,
    pub usd_price: Option<Money>,
}
Pricing information for any new regions Play may launch in the future.

This type is not used in any activity, and only used as part of another schema.

Fields

availability: Option<String>

Required. The regional availability for the new regions config. When set to AVAILABLE, the pricing information will be used for any new regions Play may launch in the future.

eur_price: Option<Money>

Required. Price in EUR to use for any new regions Play may launch in.

usd_price: Option<Money>

Required. Price in USD to use for any new regions Play may launch in.