pub struct OneTimeProductRentPurchaseOption {
pub expiration_period: Option<String>,
pub rental_period: Option<String>,
}Expand description
A purchase option that can be rented.
This type is not used in any activity, and only used as part of another schema.
Fields
expiration_period: Option<String>Optional. The amount of time the user has after starting consuming the entitlement before it is revoked. Specified in ISO 8601 format.
rental_period: Option<String>Required. The amount of time a user has the entitlement for. Starts at purchase flow completion. Specified in ISO 8601 format.