pub struct OneTimeProductTaxAndComplianceSettings {
pub is_tokenized_digital_asset: Option<bool>,
pub product_tax_category_code: Option<String>,
pub regional_tax_configs: Option<Vec<RegionalTaxConfig>>,
}Expand description
Details about taxation, Google Play policy and legal compliance for one-time products.
This type is not used in any activity, and only used as part of another schema.
Fields
is_tokenized_digital_asset: Option<bool>Whether this one-time product is declared as a product representing a tokenized digital asset.
product_tax_category_code: Option<String>Product tax category code to assign to the one-time product. Product tax category determines the transaction tax rates applied to the product. Refer to the Help Center article for more information.
regional_tax_configs: Option<Vec<RegionalTaxConfig>>Regional tax configuration.