pub struct OtherRegionsSubscriptionOfferConfig {
pub other_regions_new_subscriber_availability: Option<bool>,
}Expand description
Configuration for any new locations Play may launch in specified on a subscription offer.
This type is not used in any activity, and only used as part of another schema.
Fields
other_regions_new_subscriber_availability: Option<bool>Whether the subscription offer in any new locations Play may launch in the future. If not specified, this will default to false.