pub struct OtherRegionsSubscriptionOfferPhaseConfig {
pub absolute_discounts: Option<OtherRegionsSubscriptionOfferPhasePrices>,
pub free: Option<OtherRegionsSubscriptionOfferPhaseFreePriceOverride>,
pub other_regions_prices: Option<OtherRegionsSubscriptionOfferPhasePrices>,
pub relative_discount: Option<f64>,
}Expand description
Configuration for any new locations Play may launch in for a single offer phase.
This type is not used in any activity, and only used as part of another schema.
Fields
absolute_discounts: Option<OtherRegionsSubscriptionOfferPhasePrices>The absolute amount of money subtracted from the base plan price prorated over the phase duration that the user pays for this offer phase. For example, if the base plan price for this region is $12 for a period of 1 year, then a $1 absolute discount for a phase of a duration of 3 months would correspond to a price of $2. The resulting price may not be smaller than the minimum price allowed for any new locations Play may launch in.
free: Option<OtherRegionsSubscriptionOfferPhaseFreePriceOverride>Set to specify this offer is free to obtain.
other_regions_prices: Option<OtherRegionsSubscriptionOfferPhasePrices>The absolute price the user pays for this offer phase. The price must not be smaller than the minimum price allowed for any new locations Play may launch in.
relative_discount: Option<f64>The fraction of the base plan price prorated over the phase duration that the user pays for this offer phase. For example, if the base plan price for this region is $12 for a period of 1 year, then a 50% discount for a phase of a duration of 3 months would correspond to a price of $1.50. The discount must be specified as a fraction strictly larger than 0 and strictly smaller than 1. The resulting price will be rounded to the nearest billable unit (e.g. cents for USD). The relative discount is considered invalid if the discounted price ends up being smaller than the minimum price allowed in any new locations Play may launch in.