pub struct OtherRegionsSubscriptionOfferPhasePrices {
pub eur_price: Option<Money>,
pub usd_price: Option<Money>,
}Expand description
Pricing information for any new locations Play may launch in.
This type is not used in any activity, and only used as part of another schema.
Fields
eur_price: Option<Money>Required. Price in EUR to use for any new locations Play may launch in.
usd_price: Option<Money>Required. Price in USD to use for any new locations Play may launch in.