pub struct PageInfo {
pub result_per_page: Option<i32>,
pub start_index: Option<i32>,
pub total_results: Option<i32>,
}Expand description
Information about the current page. List operations that supports paging return only one “page” of results. This protocol buffer message describes the page that has been returned.
This type is not used in any activity, and only used as part of another schema.
Fields
result_per_page: Option<i32>Maximum number of results returned in one page. ! The number of results included in the API response.
start_index: Option<i32>Index of the first result returned in the current page.
total_results: Option<i32>Total number of results available on the backend ! The total number of results in the result set.