pub struct PartialRefund {
pub refund_id: Option<String>,
pub refund_pre_tax_amount: Option<Price>,
}Expand description
A partial refund of a transaction.
This type is not used in any activity, and only used as part of another schema.
Fields
refund_id: Option<String>Required. A unique id distinguishing this partial refund. If the refund is successful, subsequent refunds with the same id will fail. Must be unique across refunds for one individual transaction.
refund_pre_tax_amount: Option<Price>Required. The pre-tax amount of the partial refund. Should be less than the remaining pre-tax amount of the transaction.