pub struct PendingCancellation { /* private fields */ }Expand description
This is an indicator of whether there is a pending cancellation on the virtual installment plan. The cancellation will happen only after the user finished all committed payments.
This type is not used in any activity, and only used as part of another schema.