pub struct PreorderOfferDetails {
pub preorder_release_time: Option<DateTime<Utc>>,
}Expand description
Offer details information related to a preorder line item.
This type is not used in any activity, and only used as part of another schema.
Fields
preorder_release_time: Option<DateTime<Utc>>The time when a preordered item is released for a preorder purchase.