pub struct PriceStepUpConsentDetails {
pub consent_deadline_time: Option<DateTime<Utc>>,
pub new_price: Option<Money>,
pub state: Option<String>,
}Expand description
Information related to a price step-up that requires user consent.
This type is not used in any activity, and only used as part of another schema.
Fields
consent_deadline_time: Option<DateTime<Utc>>The deadline by which the user must provide consent. If consent is not provided by this time, the subscription will be canceled.
new_price: Option<Money>The new price which requires user consent.
state: Option<String>Output only. The state of the price step-up consent.