ProductPurchase

Struct ProductPurchase 

pub struct ProductPurchase {
Show 15 fields pub acknowledgement_state: Option<i32>, pub consumption_state: Option<i32>, pub developer_payload: Option<String>, pub kind: Option<String>, pub obfuscated_external_account_id: Option<String>, pub obfuscated_external_profile_id: Option<String>, pub order_id: Option<String>, pub product_id: Option<String>, pub purchase_state: Option<i32>, pub purchase_time_millis: Option<i64>, pub purchase_token: Option<String>, pub purchase_type: Option<i32>, pub quantity: Option<i32>, pub refundable_quantity: Option<i32>, pub region_code: Option<String>,
}
A ProductPurchase resource indicates the status of a user’s inapp product purchase.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

acknowledgement_state: Option<i32>

The acknowledgement state of the inapp product. Possible values are: 0. Yet to be acknowledged 1. Acknowledged

consumption_state: Option<i32>

The consumption state of the inapp product. Possible values are: 0. Yet to be consumed 1. Consumed

developer_payload: Option<String>

A developer-specified string that contains supplemental information about an order.

kind: Option<String>

This kind represents an inappPurchase object in the androidpublisher service.

obfuscated_external_account_id: Option<String>

An obfuscated version of the id that is uniquely associated with the user’s account in your app. Only present if specified using https://developer.android.com/reference/com/android/billingclient/api/BillingFlowParams.Builder#setobfuscatedaccountid when the purchase was made.

obfuscated_external_profile_id: Option<String>

An obfuscated version of the id that is uniquely associated with the user’s profile in your app. Only present if specified using https://developer.android.com/reference/com/android/billingclient/api/BillingFlowParams.Builder#setobfuscatedprofileid when the purchase was made.

order_id: Option<String>

The order id associated with the purchase of the inapp product.

product_id: Option<String>

The inapp product SKU. May not be present.

purchase_state: Option<i32>

The purchase state of the order. Possible values are: 0. Purchased 1. Canceled 2. Pending

purchase_time_millis: Option<i64>

The time the product was purchased, in milliseconds since the epoch (Jan 1, 1970).

purchase_token: Option<String>

The purchase token generated to identify this purchase. May not be present.

purchase_type: Option<i32>

The type of purchase of the inapp product. This field is only set if this purchase was not made using the standard in-app billing flow. Possible values are: 0. Test (i.e. purchased from a license testing account) 1. Promo (i.e. purchased using a promo code). Does not include Play Points purchases. 2. Rewarded (i.e. from watching a video ad instead of paying)

quantity: Option<i32>

The quantity associated with the purchase of the inapp product. If not present, the quantity is 1.

refundable_quantity: Option<i32>

The quantity eligible for refund, i.e. quantity that hasn’t been refunded. The value reflects quantity-based partial refunds and full refunds.

region_code: Option<String>

ISO 3166-1 alpha-2 billing region code of the user at the time the product was granted.