ProductPurchaseV2

Struct ProductPurchaseV2 

pub struct ProductPurchaseV2 {
    pub acknowledgement_state: Option<String>,
    pub kind: Option<String>,
    pub obfuscated_external_account_id: Option<String>,
    pub obfuscated_external_profile_id: Option<String>,
    pub order_id: Option<String>,
    pub product_line_item: Option<Vec<ProductLineItem>>,
    pub purchase_completion_time: Option<DateTime<Utc>>,
    pub purchase_state_context: Option<PurchaseStateContext>,
    pub region_code: Option<String>,
    pub test_purchase_context: Option<TestPurchaseContext>,
}
A ProductPurchaseV2 resource indicates the status of a user’s inapp product purchase.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

acknowledgement_state: Option<String>

Output only. The acknowledgement state of the purchase.

kind: Option<String>

This kind represents a ProductPurchaseV2 object in the androidpublisher service.

obfuscated_external_account_id: Option<String>

An obfuscated version of the id that is uniquely associated with the user’s account in your app. Only present if specified using https://developer.android.com/reference/com/android/billingclient/api/BillingFlowParams.Builder#setobfuscatedaccountid when the purchase was made.

obfuscated_external_profile_id: Option<String>

An obfuscated version of the id that is uniquely associated with the user’s profile in your app. Only present if specified using https://developer.android.com/reference/com/android/billingclient/api/BillingFlowParams.Builder#setobfuscatedprofileid when the purchase was made.

order_id: Option<String>

The order id associated with the purchase of the inapp product. May not be set if there is no order associated with the purchase.

product_line_item: Option<Vec<ProductLineItem>>

Contains item-level info for a ProductPurchaseV2.

purchase_completion_time: Option<DateTime<Utc>>

The time when the purchase was successful, i.e., when the PurchaseState has changed to PURCHASED. This field will not be present until the payment is complete. For example, if the user initiated a pending transaction (https://developer.android.com/google/play/billing/integrate#pending), this field will not be populated until the user successfully completes the steps required to complete the transaction.

purchase_state_context: Option<PurchaseStateContext>

Information about the purchase state of the purchase.

region_code: Option<String>

ISO 3166-1 alpha-2 billing region code of the user at the time the product was granted.

test_purchase_context: Option<TestPurchaseContext>

Information related to test purchases. This will only be set for test purchases.