pub struct PurchaseOptionTaxAndComplianceSettings {
pub withdrawal_right_type: Option<String>,
}Expand description
Details about taxation, Google Play policy and legal compliance for one-time product purchase options.
This type is not used in any activity, and only used as part of another schema.
Fields
withdrawal_right_type: Option<String>Optional. Digital content or service classification for products distributed to users in eligible regions. If unset, it defaults to WITHDRAWAL_RIGHT_DIGITAL_CONTENT. Refer to the Help Center article for more information.