pub struct RefundExternalTransactionRequest {
pub full_refund: Option<FullRefund>,
pub partial_refund: Option<PartialRefund>,
pub refund_time: Option<DateTime<Utc>>,
}Expand description
A request to refund an existing external transaction.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
full_refund: Option<FullRefund>A full-amount refund.
partial_refund: Option<PartialRefund>A partial refund.
refund_time: Option<DateTime<Utc>>Required. The time that the transaction was refunded.