pub struct RegionalSubscriptionOfferPhaseFreePriceOverride { /* private fields */ }Expand description
Represents the free price override configuration for a single phase of a subscription offer
This type is not used in any activity, and only used as part of another schema.