RegionalTaxConfig

Struct RegionalTaxConfig 

pub struct RegionalTaxConfig {
    pub eligible_for_streaming_service_tax_rate: Option<bool>,
    pub region_code: Option<String>,
    pub streaming_tax_type: Option<String>,
    pub tax_tier: Option<String>,
}
Details about taxation in a given geographical region.

This type is not used in any activity, and only used as part of another schema.

Fields

eligible_for_streaming_service_tax_rate: Option<bool>

You must tell us if your app contains streaming products to correctly charge US state and local sales tax. Field only supported in the United States.

region_code: Option<String>

Required. Region code this configuration applies to, as defined by ISO 3166-2, e.g. “US”.

streaming_tax_type: Option<String>

To collect communications or amusement taxes in the United States, choose the appropriate tax category. Learn more.

tax_tier: Option<String>

Tax tier to specify reduced tax rate. Developers who sell digital news, magazines, newspapers, books, or audiobooks in various regions may be eligible for reduced tax rates. Learn more.