pub struct RemoteInAppUpdateDataPerBundle {
pub recovered_device_count: Option<i64>,
pub total_device_count: Option<i64>,
pub version_code: Option<i64>,
}Expand description
Data related to the recovery action at bundle level.
This type is not used in any activity, and only used as part of another schema.
Fields
recovered_device_count: Option<i64>Total number of devices which have been rescued.
total_device_count: Option<i64>Total number of devices affected by this recovery action associated with bundle of the app.
version_code: Option<i64>Version Code corresponding to the target bundle.