pub struct SdkVersionTargeting {
pub alternatives: Option<Vec<SdkVersion>>,
pub value: Option<Vec<SdkVersion>>,
}Expand description
Targeting based on sdk version.
This type is not used in any activity, and only used as part of another schema.
Fields
alternatives: Option<Vec<SdkVersion>>Targeting of other sibling directories that were in the Bundle. For main splits this is targeting of other main splits.
value: Option<Vec<SdkVersion>>Value of an sdk version.