pub struct SplitApkVariant {
pub apk_set: Option<Vec<ApkSet>>,
pub targeting: Option<VariantTargeting>,
pub variant_number: Option<i32>,
}Expand description
Variant is a group of APKs that covers a part of the device configuration space. APKs from multiple variants are never combined on one device.
This type is not used in any activity, and only used as part of another schema.
Fields
apk_set: Option<Vec<ApkSet>>Set of APKs, one set per module.
targeting: Option<VariantTargeting>Variant-level targeting.
variant_number: Option<i32>Number of the variant, starting at 0 (unless overridden). A device will receive APKs from the first variant that matches the device configuration, with higher variant numbers having priority over lower variant numbers.