pub struct SubscribeWithGoogleInfo {
pub email_address: Option<String>,
pub family_name: Option<String>,
pub given_name: Option<String>,
pub profile_id: Option<String>,
pub profile_name: Option<String>,
}Expand description
Information associated with purchases made with ‘Subscribe with Google’.
This type is not used in any activity, and only used as part of another schema.
Fields
email_address: Option<String>The email address of the user when the subscription was purchased.
family_name: Option<String>The family name of the user when the subscription was purchased.
given_name: Option<String>The given name of the user when the subscription was purchased.
profile_id: Option<String>The Google profile id of the user when the subscription was purchased.
profile_name: Option<String>The profile name of the user when the subscription was purchased.