pub struct SubscriptionItemPriceChangeDetails {
pub expected_new_price_charge_time: Option<DateTime<Utc>>,
pub new_price: Option<Money>,
pub price_change_mode: Option<String>,
pub price_change_state: Option<String>,
}Expand description
Price change related information of a subscription item.
This type is not used in any activity, and only used as part of another schema.
Fields
expected_new_price_charge_time: Option<DateTime<Utc>>The renewal time at which the price change will become effective for the user. This is subject to change(to a future time) due to cases where the renewal time shifts like pause. This field is only populated if the price change has not taken effect.
new_price: Option<Money>New recurring price for the subscription item.
price_change_mode: Option<String>Price change mode specifies how the subscription item price is changing.
price_change_state: Option<String>State the price change is currently in.