SubscriptionOffer

Struct SubscriptionOffer 

pub struct SubscriptionOffer {
    pub base_plan_id: Option<String>,
    pub offer_id: Option<String>,
    pub offer_tags: Option<Vec<OfferTag>>,
    pub other_regions_config: Option<OtherRegionsSubscriptionOfferConfig>,
    pub package_name: Option<String>,
    pub phases: Option<Vec<SubscriptionOfferPhase>>,
    pub product_id: Option<String>,
    pub regional_configs: Option<Vec<RegionalSubscriptionOfferConfig>>,
    pub state: Option<String>,
    pub targeting: Option<SubscriptionOfferTargeting>,
}
A single, temporary offer

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

base_plan_id: Option<String>

Required. Immutable. The ID of the base plan to which this offer is an extension.

offer_id: Option<String>

Required. Immutable. Unique ID of this subscription offer. Must be unique within the base plan.

offer_tags: Option<Vec<OfferTag>>

List of up to 20 custom tags specified for this offer, and returned to the app through the billing library.

other_regions_config: Option<OtherRegionsSubscriptionOfferConfig>

The configuration for any new locations Play may launch in the future.

package_name: Option<String>

Required. Immutable. The package name of the app the parent subscription belongs to.

phases: Option<Vec<SubscriptionOfferPhase>>

Required. The phases of this subscription offer. Must contain at least one and at most two entries. Users will always receive all these phases in the specified order.

product_id: Option<String>

Required. Immutable. The ID of the parent subscription this offer belongs to.

regional_configs: Option<Vec<RegionalSubscriptionOfferConfig>>

Required. The region-specific configuration of this offer. Must contain at least one entry.

state: Option<String>

Output only. The current state of this offer. Can be changed using Activate and Deactivate actions. NB: the base plan state supersedes this state, so an active offer may not be available if the base plan is not active.

targeting: Option<SubscriptionOfferTargeting>

The requirements that users need to fulfil to be eligible for this offer. Represents the requirements that Play will evaluate to decide whether an offer should be returned. Developers may further filter these offers themselves.