pub struct SubscriptionOfferPhase {
pub duration: Option<String>,
pub other_regions_config: Option<OtherRegionsSubscriptionOfferPhaseConfig>,
pub recurrence_count: Option<i32>,
pub regional_configs: Option<Vec<RegionalSubscriptionOfferPhaseConfig>>,
}Expand description
A single phase of a subscription offer.
This type is not used in any activity, and only used as part of another schema.
Fields
duration: Option<String>Required. The duration of a single recurrence of this phase. Specified in ISO 8601 format.
other_regions_config: Option<OtherRegionsSubscriptionOfferPhaseConfig>Pricing information for any new locations Play may launch in.
recurrence_count: Option<i32>Required. The number of times this phase repeats. If this offer phase is not free, each recurrence charges the user the price of this offer phase.
regional_configs: Option<Vec<RegionalSubscriptionOfferPhaseConfig>>Required. The region-specific configuration of this offer phase. This list must contain exactly one entry for each region for which the subscription offer has a regional config.