pub struct SubscriptionOfferTargeting {
pub acquisition_rule: Option<AcquisitionTargetingRule>,
pub upgrade_rule: Option<UpgradeTargetingRule>,
}Expand description
Defines the rule a user needs to satisfy to receive this offer.
This type is not used in any activity, and only used as part of another schema.
Fields
acquisition_rule: Option<AcquisitionTargetingRule>Offer targeting rule for new user acquisition.
upgrade_rule: Option<UpgradeTargetingRule>Offer targeting rule for upgrading users’ existing plans.