pub struct SubscriptionPriceChange {
pub new_price: Option<Price>,
pub state: Option<i32>,
}Expand description
Contains the price change information for a subscription that can be used to control the user journey for the price change in the app. This can be in the form of seeking confirmation from the user or tailoring the experience for a successful conversion.
This type is not used in any activity, and only used as part of another schema.
Fields
new_price: Option<Price>The new price the subscription will renew with if the price change is accepted by the user.
state: Option<i32>The current state of the price change. Possible values are: 0. Outstanding: State for a pending price change waiting for the user to agree. In this state, you can optionally seek confirmation from the user using the In-App API. 1. Accepted: State for an accepted price change that the subscription will renew with unless it’s canceled. The price change takes effect on a future date when the subscription renews. Note that the change might not occur when the subscription is renewed next.