SubscriptionPurchasesAcknowledgeRequest

Struct SubscriptionPurchasesAcknowledgeRequest 

pub struct SubscriptionPurchasesAcknowledgeRequest {
    pub developer_payload: Option<String>,
    pub external_account_ids: Option<ExternalAccountIds>,
}
Request for the purchases.subscriptions.acknowledge API.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

developer_payload: Option<String>

Payload to attach to the purchase.

external_account_ids: Option<ExternalAccountIds>

Optional. User account identifier in your app.