pub struct SystemApksListResponse {
pub variants: Option<Vec<Variant>>,
}Expand description
Response to list previously created system APK variants.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- variants list systemapks (response)
Fields
variants: Option<Vec<Variant>>All system APK variants created.