pub struct Targeting {
pub all_users: Option<AllUsers>,
pub android_sdks: Option<AndroidSdks>,
pub regions: Option<Regions>,
pub version_list: Option<AppVersionList>,
pub version_range: Option<AppVersionRange>,
}Expand description
Targeting details for a recovery action such as regions, android sdk levels, app versions etc.
This type is not used in any activity, and only used as part of another schema.
Fields
all_users: Option<AllUsers>All users are targeted.
android_sdks: Option<AndroidSdks>Targeting is based on android api levels of devices.
regions: Option<Regions>Targeting is based on the user account region.
version_list: Option<AppVersionList>Target version codes as a list.
version_range: Option<AppVersionRange>Target version codes as a range.