pub struct TargetingRuleScopeAnySubscriptionInApp { /* private fields */ }Expand description
Represents the targeting rule scope corresponding to any subscription in the parent app.
This type is not used in any activity, and only used as part of another schema.