pub struct TargetingRuleScopeThisSubscription { /* private fields */ }Expand description
Represents the targeting rule scope corresponding to the subscriptions in which this offer is defined.
This type is not used in any activity, and only used as part of another schema.