pub struct TargetingUpdate {
pub all_users: Option<AllUsers>,
pub android_sdks: Option<AndroidSdks>,
pub regions: Option<Regions>,
}Expand description
Update type for targeting. Note it is always a subset Targeting.
This type is not used in any activity, and only used as part of another schema.
Fields
all_users: Option<AllUsers>All users are targeted.
android_sdks: Option<AndroidSdks>Additional android sdk levels are targeted by the recovery action.
regions: Option<Regions>Additional regions are targeted by the recovery action.