TrackCountryAvailability

Struct TrackCountryAvailability 

pub struct TrackCountryAvailability {
    pub countries: Option<Vec<TrackTargetedCountry>>,
    pub rest_of_world: Option<bool>,
    pub sync_with_production: Option<bool>,
}
Resource for per-track country availability information.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

countries: Option<Vec<TrackTargetedCountry>>

A list of one or more countries where artifacts in this track are available. This list includes all countries that are targeted by the track, even if only specific carriers are targeted in that country.

rest_of_world: Option<bool>

Whether artifacts in this track are available to “rest of the world” countries.

sync_with_production: Option<bool>

Whether this track’s availability is synced with the default production track. See https://support.google.com/googleplay/android-developer/answer/7550024 for more information on syncing country availability with production. Note that if this is true, the returned “countries” and “rest_of_world” fields will reflect the values for the default production track.