pub struct TrackTargetedCountry {
pub country_code: Option<String>,
}Expand description
Representation of a single country where the contents of a track are available.
This type is not used in any activity, and only used as part of another schema.
Fields
country_code: Option<String>The country to target, as a two-letter CLDR code.