pub struct UpdateOneTimeProductOfferRequest {
pub allow_missing: Option<bool>,
pub latency_tolerance: Option<String>,
pub one_time_product_offer: Option<OneTimeProductOffer>,
pub regions_version: Option<RegionsVersion>,
pub update_mask: Option<FieldMask>,
}Expand description
Request message for UpdateOneTimeProductOffer.
This type is not used in any activity, and only used as part of another schema.
Fields
allow_missing: Option<bool>Optional. If set to true, and the offer with the given package_name, product_id, purchase_option_id and offer_id doesn’t exist, an offer will be created. If a new offer is created, the update_mask is ignored.
latency_tolerance: Option<String>Optional. The latency tolerance for the propagation of this offer update. Defaults to latency-sensitive.
one_time_product_offer: Option<OneTimeProductOffer>Required. The one-time product offer to update.
regions_version: Option<RegionsVersion>Required. The version of the available regions being used for the offer.
update_mask: Option<FieldMask>Required. The list of fields to be updated.