UpdateOneTimeProductOfferStateRequest

Struct UpdateOneTimeProductOfferStateRequest 

pub struct UpdateOneTimeProductOfferStateRequest {
    pub activate_one_time_product_offer_request: Option<ActivateOneTimeProductOfferRequest>,
    pub cancel_one_time_product_offer_request: Option<CancelOneTimeProductOfferRequest>,
    pub deactivate_one_time_product_offer_request: Option<DeactivateOneTimeProductOfferRequest>,
}
Request message to update the state of a one-time product offer.

This type is not used in any activity, and only used as part of another schema.

Fields

activate_one_time_product_offer_request: Option<ActivateOneTimeProductOfferRequest>

Activates an offer. Once activated, the offer is available to users, as long as its conditions are met.

cancel_one_time_product_offer_request: Option<CancelOneTimeProductOfferRequest>

Cancels an offer. Once cancelled, the offer is not available to users. Any pending orders related to this offer will be cancelled. This state transition is specific to pre-orders.

deactivate_one_time_product_offer_request: Option<DeactivateOneTimeProductOfferRequest>

Deactivates an offer. Once deactivated, the offer is no longer available to users. This state transition is specific to discounted offers.