pub struct UpdateOneTimeProductRequest {
pub allow_missing: Option<bool>,
pub latency_tolerance: Option<String>,
pub one_time_product: Option<OneTimeProduct>,
pub regions_version: Option<RegionsVersion>,
pub update_mask: Option<FieldMask>,
}Expand description
Request message for UpdateOneTimeProduct.
This type is not used in any activity, and only used as part of another schema.
Fields
allow_missing: Option<bool>Optional. If set to true, and the one-time product with the given package_name and product_id doesn’t exist, the one-time product will be created. If a new one-time product is created, update_mask is ignored.
latency_tolerance: Option<String>Optional. The latency tolerance for the propagation of this product upsert. Defaults to latency-sensitive.
one_time_product: Option<OneTimeProduct>Required. The one-time product to upsert.
regions_version: Option<RegionsVersion>Required. The version of the available regions being used for the one-time product.
update_mask: Option<FieldMask>Required. The list of fields to be updated.