pub struct UpdateSubscriptionOfferRequest {
pub allow_missing: Option<bool>,
pub latency_tolerance: Option<String>,
pub regions_version: Option<RegionsVersion>,
pub subscription_offer: Option<SubscriptionOffer>,
pub update_mask: Option<FieldMask>,
}Expand description
Request message for UpdateSubscriptionOffer.
This type is not used in any activity, and only used as part of another schema.
Fields
allow_missing: Option<bool>Optional. If set to true, and the subscription offer with the given package_name, product_id, base_plan_id and offer_id doesn’t exist, an offer will be created. If a new offer is created, update_mask is ignored.
latency_tolerance: Option<String>Optional. The latency tolerance for the propagation of this product update. Defaults to latency-sensitive.
regions_version: Option<RegionsVersion>Required. The version of the available regions being used for the subscription_offer.
subscription_offer: Option<SubscriptionOffer>Required. The subscription offer to update.
update_mask: Option<FieldMask>Required. The list of fields to be updated.