pub struct UpgradeTargetingRule {
pub billing_period_duration: Option<String>,
pub once_per_user: Option<bool>,
pub scope: Option<TargetingRuleScope>,
}Expand description
Represents a targeting rule of the form: User currently has {scope} [with billing period {billing_period}].
This type is not used in any activity, and only used as part of another schema.
Fields
billing_period_duration: Option<String>The specific billing period duration, specified in ISO 8601 format, that a user must be currently subscribed to to be eligible for this rule. If not specified, users subscribed to any billing period are matched.
once_per_user: Option<bool>Limit this offer to only once per user. If set to true, a user can never be eligible for this offer again if they ever subscribed to this offer.
scope: Option<TargetingRuleScope>Required. The scope of subscriptions this rule considers. Only allows “this subscription” and “specific subscription in app”.