pub struct UserInitiatedCancellation {
pub cancel_survey_result: Option<CancelSurveyResult>,
pub cancel_time: Option<DateTime<Utc>>,
}Expand description
Information specific to cancellations initiated by users.
This type is not used in any activity, and only used as part of another schema.
Fields
cancel_survey_result: Option<CancelSurveyResult>Information provided by the user when they complete the subscription cancellation flow (cancellation reason survey).
cancel_time: Option<DateTime<Utc>>The time at which the subscription was canceled by the user. The user might still have access to the subscription after this time. Use line_items.expiry_time to determine if a user still has access.