[][src]Struct google_androidpublisher3::InternalappsharingartifactMethods

pub struct InternalappsharingartifactMethods<'a, C, A> where
    C: 'a,
    A: 'a, 
{ /* fields omitted */ }

A builder providing access to all methods supported on internalappsharingartifact resources. It is not used directly, but through the AndroidPublisher hub.

Example

Instantiate a resource builder

extern crate hyper;
extern crate hyper_rustls;
extern crate yup_oauth2 as oauth2;
extern crate google_androidpublisher3 as androidpublisher3;
 
use std::default::Default;
use oauth2::{Authenticator, DefaultAuthenticatorDelegate, ApplicationSecret, MemoryStorage};
use androidpublisher3::AndroidPublisher;
 
let secret: ApplicationSecret = Default::default();
let auth = Authenticator::new(&secret, DefaultAuthenticatorDelegate,
                              hyper::Client::with_connector(hyper::net::HttpsConnector::new(hyper_rustls::TlsClient::new())),
                              <MemoryStorage as Default>::default(), None);
let mut hub = AndroidPublisher::new(hyper::Client::with_connector(hyper::net::HttpsConnector::new(hyper_rustls::TlsClient::new())), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `uploadapk(...)` and `uploadbundle(...)`
// to build up your call.
let rb = hub.internalappsharingartifacts();

Methods

impl<'a, C, A> InternalappsharingartifactMethods<'a, C, A>[src]

pub fn uploadapk(
    &self,
    package_name: &str
) -> InternalappsharingartifactUploadapkCall<'a, C, A>
[src]

Create a builder to help you perform the following task:

Uploads an APK to internal app sharing. If you are using the Google API client libraries, please increase the timeout of the http request before calling this endpoint (a timeout of 2 minutes is recommended). See: https://developers.google.com/api-client-library/java/google-api-java-client/errors for an example in java.

Arguments

  • packageName - Unique identifier for the Android app; for example, "com.spiffygame".

pub fn uploadbundle(
    &self,
    package_name: &str
) -> InternalappsharingartifactUploadbundleCall<'a, C, A>
[src]

Create a builder to help you perform the following task:

Uploads an app bundle to internal app sharing. If you are using the Google API client libraries, please increase the timeout of the http request before calling this endpoint (a timeout of 2 minutes is recommended). See: https://developers.google.com/api-client-library/java/google-api-java-client/errors for an example in java.

Arguments

  • packageName - Unique identifier for the Android app; for example, "com.spiffygame".