pub struct AppRecoveryAction {
pub app_recovery_id: Option<i64>,
pub cancel_time: Option<DateTime<Utc>>,
pub create_time: Option<DateTime<Utc>>,
pub deploy_time: Option<DateTime<Utc>>,
pub last_update_time: Option<DateTime<Utc>>,
pub remote_in_app_update_data: Option<RemoteInAppUpdateData>,
pub status: Option<String>,
pub targeting: Option<Targeting>,
}Expand description
Information about an app recovery action.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- create apprecovery (response)
Fields
app_recovery_id: Option<i64>ID corresponding to the app recovery action.
cancel_time: Option<DateTime<Utc>>Timestamp of when the app recovery action is canceled by the developer. Only set if the recovery action has been canceled.
create_time: Option<DateTime<Utc>>Timestamp of when the app recovery action is created by the developer. It is always set after creation of the recovery action.
deploy_time: Option<DateTime<Utc>>Timestamp of when the app recovery action is deployed to the users. Only set if the recovery action has been deployed.
last_update_time: Option<DateTime<Utc>>Timestamp of when the developer last updated recovery action. In case the action is cancelled, it corresponds to cancellation time. It is always set after creation of the recovery action.
remote_in_app_update_data: Option<RemoteInAppUpdateData>Data about the remote in-app update action such as such as recovered user base, recoverable user base etc. Set only if the recovery action type is Remote In-App Update.
status: Option<String>The status of the recovery action.
targeting: Option<Targeting>Specifies targeting criteria for the recovery action such as regions, android sdk versions, app versions etc.