pub struct InternalAppSharingArtifact {
pub certificate_fingerprint: Option<String>,
pub download_url: Option<String>,
pub sha256: Option<String>,
}Expand description
An artifact resource which gets created when uploading an APK or Android App Bundle through internal app sharing.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- uploadapk internalappsharingartifacts (response)
- uploadbundle internalappsharingartifacts (response)
Fields
certificate_fingerprint: Option<String>The sha256 fingerprint of the certificate used to sign the generated artifact.
download_url: Option<String>The download URL generated for the uploaded artifact. Users that are authorized to download can follow the link to the Play Store app to install it.
sha256: Option<String>The sha256 hash of the artifact represented as a lowercase hexadecimal number, matching the output of the sha256sum command.