pub struct IntroductoryPriceInfo {
pub introductory_price_amount_micros: Option<i64>,
pub introductory_price_currency_code: Option<String>,
pub introductory_price_cycles: Option<i32>,
pub introductory_price_period: Option<String>,
}Expand description
Contains the introductory price information for a subscription.
This type is not used in any activity, and only used as part of another schema.
Fields
introductory_price_amount_micros: Option<i64>Introductory price of the subscription, not including tax. The currency is the same as price_currency_code. Price is expressed in micro-units, where 1,000,000 micro-units represents one unit of the currency. For example, if the subscription price is €1.99, price_amount_micros is 1990000.
introductory_price_currency_code: Option<String>ISO 4217 currency code for the introductory subscription price. For example, if the price is specified in British pounds sterling, price_currency_code is “GBP”.
introductory_price_cycles: Option<i32>The number of billing period to offer introductory pricing.
introductory_price_period: Option<String>Introductory price period, specified in ISO 8601 format. Common values are (but not limited to) “P1W” (one week), “P1M” (one month), “P3M” (three months), “P6M” (six months), and “P1Y” (one year).