pub struct MonetizationMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on monetization resources.
It is not used directly, but through the AndroidPublisher hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_androidpublisher3 as androidpublisher3;
use androidpublisher3::{AndroidPublisher, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = AndroidPublisher::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `convert_region_prices(...)`, `onetimeproducts_batch_delete(...)`, `onetimeproducts_batch_get(...)`, `onetimeproducts_batch_update(...)`, `onetimeproducts_delete(...)`, `onetimeproducts_get(...)`, `onetimeproducts_list(...)`, `onetimeproducts_patch(...)`, `onetimeproducts_purchase_options_batch_delete(...)`, `onetimeproducts_purchase_options_batch_update_states(...)`, `onetimeproducts_purchase_options_offers_activate(...)`, `onetimeproducts_purchase_options_offers_batch_delete(...)`, `onetimeproducts_purchase_options_offers_batch_get(...)`, `onetimeproducts_purchase_options_offers_batch_update(...)`, `onetimeproducts_purchase_options_offers_batch_update_states(...)`, `onetimeproducts_purchase_options_offers_cancel(...)`, `onetimeproducts_purchase_options_offers_deactivate(...)`, `onetimeproducts_purchase_options_offers_list(...)`, `subscriptions_archive(...)`, `subscriptions_base_plans_activate(...)`, `subscriptions_base_plans_batch_migrate_prices(...)`, `subscriptions_base_plans_batch_update_states(...)`, `subscriptions_base_plans_deactivate(...)`, `subscriptions_base_plans_delete(...)`, `subscriptions_base_plans_migrate_prices(...)`, `subscriptions_base_plans_offers_activate(...)`, `subscriptions_base_plans_offers_batch_get(...)`, `subscriptions_base_plans_offers_batch_update(...)`, `subscriptions_base_plans_offers_batch_update_states(...)`, `subscriptions_base_plans_offers_create(...)`, `subscriptions_base_plans_offers_deactivate(...)`, `subscriptions_base_plans_offers_delete(...)`, `subscriptions_base_plans_offers_get(...)`, `subscriptions_base_plans_offers_list(...)`, `subscriptions_base_plans_offers_patch(...)`, `subscriptions_batch_get(...)`, `subscriptions_batch_update(...)`, `subscriptions_create(...)`, `subscriptions_delete(...)`, `subscriptions_get(...)`, `subscriptions_list(...)` and `subscriptions_patch(...)`
// to build up your call.
let rb = hub.monetization();Implementations
Sourceimpl<'a, C> MonetizationMethods<'a, C>
impl<'a, C> MonetizationMethods<'a, C>
Sourcepub fn onetimeproducts_purchase_options_offers_activate(
&self,
request: ActivateOneTimeProductOfferRequest,
package_name: &str,
product_id: &str,
purchase_option_id: &str,
offer_id: &str,
) -> MonetizationOnetimeproductPurchaseOptionOfferActivateCall<'a, C>
pub fn onetimeproducts_purchase_options_offers_activate( &self, request: ActivateOneTimeProductOfferRequest, package_name: &str, product_id: &str, purchase_option_id: &str, offer_id: &str, ) -> MonetizationOnetimeproductPurchaseOptionOfferActivateCall<'a, C>
Create a builder to help you perform the following task:
Activates a one-time product offer.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the offer to activate.productId- Required. The parent one-time product (ID) of the offer to activate.purchaseOptionId- Required. The parent purchase option (ID) of the offer to activate.offerId- Required. The offer ID of the offer to activate.
Sourcepub fn onetimeproducts_purchase_options_offers_batch_delete(
&self,
request: BatchDeleteOneTimeProductOffersRequest,
package_name: &str,
product_id: &str,
purchase_option_id: &str,
) -> MonetizationOnetimeproductPurchaseOptionOfferBatchDeleteCall<'a, C>
pub fn onetimeproducts_purchase_options_offers_batch_delete( &self, request: BatchDeleteOneTimeProductOffersRequest, package_name: &str, product_id: &str, purchase_option_id: &str, ) -> MonetizationOnetimeproductPurchaseOptionOfferBatchDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes one or more one-time product offers.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the offers to delete. Must be equal to the package_name field on all the OneTimeProductOffer resources.productId- Required. The product ID of the parent one-time product, if all offers to delete belong to the same product. If this request spans multiple one-time products, set this field to “-”.purchaseOptionId- Required. The parent purchase option (ID) for which the offers should be deleted. May be specified as ‘-’ to update offers from multiple purchase options.
Sourcepub fn onetimeproducts_purchase_options_offers_batch_get(
&self,
request: BatchGetOneTimeProductOffersRequest,
package_name: &str,
product_id: &str,
purchase_option_id: &str,
) -> MonetizationOnetimeproductPurchaseOptionOfferBatchGetCall<'a, C>
pub fn onetimeproducts_purchase_options_offers_batch_get( &self, request: BatchGetOneTimeProductOffersRequest, package_name: &str, product_id: &str, purchase_option_id: &str, ) -> MonetizationOnetimeproductPurchaseOptionOfferBatchGetCall<'a, C>
Create a builder to help you perform the following task:
Reads one or more one-time product offers.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the updated offers. Must be equal to the package_name field on all the updated OneTimeProductOffer resources.productId- Required. The product ID of the parent one-time product, if all updated offers belong to the same product. If this request spans multiple one-time products, set this field to “-”.purchaseOptionId- Required. The parent purchase option (ID) for which the offers should be updated. May be specified as ‘-’ to update offers from multiple purchase options.
Sourcepub fn onetimeproducts_purchase_options_offers_batch_update(
&self,
request: BatchUpdateOneTimeProductOffersRequest,
package_name: &str,
product_id: &str,
purchase_option_id: &str,
) -> MonetizationOnetimeproductPurchaseOptionOfferBatchUpdateCall<'a, C>
pub fn onetimeproducts_purchase_options_offers_batch_update( &self, request: BatchUpdateOneTimeProductOffersRequest, package_name: &str, product_id: &str, purchase_option_id: &str, ) -> MonetizationOnetimeproductPurchaseOptionOfferBatchUpdateCall<'a, C>
Create a builder to help you perform the following task:
Creates or updates one or more one-time product offers.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the updated offers. Must be equal to the package_name field on all the updated OneTimeProductOffer resources.productId- Required. The product ID of the parent one-time product, if all updated offers belong to the same product. If this request spans multiple one-time products, set this field to “-”.purchaseOptionId- Required. The parent purchase option (ID) for which the offers should be updated. May be specified as ‘-’ to update offers from multiple purchase options.
Sourcepub fn onetimeproducts_purchase_options_offers_batch_update_states(
&self,
request: BatchUpdateOneTimeProductOfferStatesRequest,
package_name: &str,
product_id: &str,
purchase_option_id: &str,
) -> MonetizationOnetimeproductPurchaseOptionOfferBatchUpdateStateCall<'a, C>
pub fn onetimeproducts_purchase_options_offers_batch_update_states( &self, request: BatchUpdateOneTimeProductOfferStatesRequest, package_name: &str, product_id: &str, purchase_option_id: &str, ) -> MonetizationOnetimeproductPurchaseOptionOfferBatchUpdateStateCall<'a, C>
Create a builder to help you perform the following task:
Updates a batch of one-time product offer states.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the updated one-time product offers.productId- Required. The product ID of the parent one-time product, if all updated offers belong to the same one-time product. If this batch update spans multiple one-time products, set this field to “-”.purchaseOptionId- Required. The purchase option ID of the parent purchase option, if all updated offers belong to the same purchase option. If this batch update spans multiple purchase options, set this field to “-”.
Sourcepub fn onetimeproducts_purchase_options_offers_cancel(
&self,
request: CancelOneTimeProductOfferRequest,
package_name: &str,
product_id: &str,
purchase_option_id: &str,
offer_id: &str,
) -> MonetizationOnetimeproductPurchaseOptionOfferCancelCall<'a, C>
pub fn onetimeproducts_purchase_options_offers_cancel( &self, request: CancelOneTimeProductOfferRequest, package_name: &str, product_id: &str, purchase_option_id: &str, offer_id: &str, ) -> MonetizationOnetimeproductPurchaseOptionOfferCancelCall<'a, C>
Create a builder to help you perform the following task:
Cancels a one-time product offer.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the offer to cancel.productId- Required. The parent one-time product (ID) of the offer to cancel.purchaseOptionId- Required. The parent purchase option (ID) of the offer to cancel.offerId- Required. The offer ID of the offer to cancel.
Sourcepub fn onetimeproducts_purchase_options_offers_deactivate(
&self,
request: DeactivateOneTimeProductOfferRequest,
package_name: &str,
product_id: &str,
purchase_option_id: &str,
offer_id: &str,
) -> MonetizationOnetimeproductPurchaseOptionOfferDeactivateCall<'a, C>
pub fn onetimeproducts_purchase_options_offers_deactivate( &self, request: DeactivateOneTimeProductOfferRequest, package_name: &str, product_id: &str, purchase_option_id: &str, offer_id: &str, ) -> MonetizationOnetimeproductPurchaseOptionOfferDeactivateCall<'a, C>
Create a builder to help you perform the following task:
Deactivates a one-time product offer.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the offer to deactivate.productId- Required. The parent one-time product (ID) of the offer to deactivate.purchaseOptionId- Required. The parent purchase option (ID) of the offer to deactivate.offerId- Required. The offer ID of the offer to deactivate.
Sourcepub fn onetimeproducts_purchase_options_offers_list(
&self,
package_name: &str,
product_id: &str,
purchase_option_id: &str,
) -> MonetizationOnetimeproductPurchaseOptionOfferListCall<'a, C>
pub fn onetimeproducts_purchase_options_offers_list( &self, package_name: &str, product_id: &str, purchase_option_id: &str, ) -> MonetizationOnetimeproductPurchaseOptionOfferListCall<'a, C>
Create a builder to help you perform the following task:
Lists all offers under a given app, product, or purchase option.
Arguments
packageName- Required. The parent app (package name) for which the offers should be read.productId- Required. The parent one-time product (ID) for which the offers should be read. May be specified as ‘-’ to read all offers under an app.purchaseOptionId- Required. The parent purchase option (ID) for which the offers should be read. May be specified as ‘-’ to read all offers under a one-time product or an app. Must be specified as ‘-’ if product_id is specified as ‘-’.
Sourcepub fn onetimeproducts_purchase_options_batch_delete(
&self,
request: BatchDeletePurchaseOptionsRequest,
package_name: &str,
product_id: &str,
) -> MonetizationOnetimeproductPurchaseOptionBatchDeleteCall<'a, C>
pub fn onetimeproducts_purchase_options_batch_delete( &self, request: BatchDeletePurchaseOptionsRequest, package_name: &str, product_id: &str, ) -> MonetizationOnetimeproductPurchaseOptionBatchDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes purchase options across one or multiple one-time products. By default this operation will fail if there are any existing offers under the deleted purchase options. Use the force parameter to override the default behavior.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the purchase options to delete.productId- Required. The product ID of the parent one-time product, if all purchase options to delete belong to the same one-time product. If this batch delete spans multiple one-time products, set this field to “-”.
Sourcepub fn onetimeproducts_purchase_options_batch_update_states(
&self,
request: BatchUpdatePurchaseOptionStatesRequest,
package_name: &str,
product_id: &str,
) -> MonetizationOnetimeproductPurchaseOptionBatchUpdateStateCall<'a, C>
pub fn onetimeproducts_purchase_options_batch_update_states( &self, request: BatchUpdatePurchaseOptionStatesRequest, package_name: &str, product_id: &str, ) -> MonetizationOnetimeproductPurchaseOptionBatchUpdateStateCall<'a, C>
Create a builder to help you perform the following task:
Activates or deactivates purchase options across one or multiple one-time products.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the updated purchase options.productId- Required. The product ID of the parent one-time product, if all updated purchase options belong to the same one-time product. If this batch update spans multiple one-time products, set this field to “-”.
Sourcepub fn onetimeproducts_batch_delete(
&self,
request: BatchDeleteOneTimeProductsRequest,
package_name: &str,
) -> MonetizationOnetimeproductBatchDeleteCall<'a, C>
pub fn onetimeproducts_batch_delete( &self, request: BatchDeleteOneTimeProductsRequest, package_name: &str, ) -> MonetizationOnetimeproductBatchDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes one or more one-time products.
Arguments
request- No description provided.packageName- Required. The parent app (package name) for which the one-time products should be deleted. Must be equal to the package_name field on all the OneTimeProduct resources.
Sourcepub fn onetimeproducts_batch_get(
&self,
package_name: &str,
) -> MonetizationOnetimeproductBatchGetCall<'a, C>
pub fn onetimeproducts_batch_get( &self, package_name: &str, ) -> MonetizationOnetimeproductBatchGetCall<'a, C>
Create a builder to help you perform the following task:
Reads one or more one-time products.
Arguments
packageName- Required. The parent app (package name) for which the products should be retrieved. Must be equal to the package_name field on all requests.
Sourcepub fn onetimeproducts_batch_update(
&self,
request: BatchUpdateOneTimeProductsRequest,
package_name: &str,
) -> MonetizationOnetimeproductBatchUpdateCall<'a, C>
pub fn onetimeproducts_batch_update( &self, request: BatchUpdateOneTimeProductsRequest, package_name: &str, ) -> MonetizationOnetimeproductBatchUpdateCall<'a, C>
Create a builder to help you perform the following task:
Creates or updates one or more one-time products.
Arguments
request- No description provided.packageName- Required. The parent app (package name) for which the one-time products should be updated. Must be equal to the package_name field on all the OneTimeProduct resources.
Sourcepub fn onetimeproducts_delete(
&self,
package_name: &str,
product_id: &str,
) -> MonetizationOnetimeproductDeleteCall<'a, C>
pub fn onetimeproducts_delete( &self, package_name: &str, product_id: &str, ) -> MonetizationOnetimeproductDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a one-time product.
Arguments
packageName- Required. The parent app (package name) of the one-time product to delete.productId- Required. The one-time product ID of the one-time product to delete.
Sourcepub fn onetimeproducts_get(
&self,
package_name: &str,
product_id: &str,
) -> MonetizationOnetimeproductGetCall<'a, C>
pub fn onetimeproducts_get( &self, package_name: &str, product_id: &str, ) -> MonetizationOnetimeproductGetCall<'a, C>
Create a builder to help you perform the following task:
Reads a single one-time product.
Arguments
packageName- Required. The parent app (package name) of the product to retrieve.productId- Required. The product ID of the product to retrieve.
Sourcepub fn onetimeproducts_list(
&self,
package_name: &str,
) -> MonetizationOnetimeproductListCall<'a, C>
pub fn onetimeproducts_list( &self, package_name: &str, ) -> MonetizationOnetimeproductListCall<'a, C>
Create a builder to help you perform the following task:
Lists all one-time products under a given app.
Arguments
packageName- Required. The parent app (package name) for which the one-time product should be read.
Sourcepub fn onetimeproducts_patch(
&self,
request: OneTimeProduct,
package_name: &str,
product_id: &str,
) -> MonetizationOnetimeproductPatchCall<'a, C>
pub fn onetimeproducts_patch( &self, request: OneTimeProduct, package_name: &str, product_id: &str, ) -> MonetizationOnetimeproductPatchCall<'a, C>
Create a builder to help you perform the following task:
Creates or updates a one-time product.
Arguments
request- No description provided.packageName- Required. Immutable. Package name of the parent app.productId- Required. Immutable. Unique product ID of the product. Unique within the parent app. Product IDs must start with a number or lowercase letter, and can contain numbers (0-9), lowercase letters (a-z), underscores (_), and periods (.).
Sourcepub fn subscriptions_base_plans_offers_activate(
&self,
request: ActivateSubscriptionOfferRequest,
package_name: &str,
product_id: &str,
base_plan_id: &str,
offer_id: &str,
) -> MonetizationSubscriptionBasePlanOfferActivateCall<'a, C>
pub fn subscriptions_base_plans_offers_activate( &self, request: ActivateSubscriptionOfferRequest, package_name: &str, product_id: &str, base_plan_id: &str, offer_id: &str, ) -> MonetizationSubscriptionBasePlanOfferActivateCall<'a, C>
Create a builder to help you perform the following task:
Activates a subscription offer. Once activated, subscription offers will be available to new subscribers.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the offer to activate.productId- Required. The parent subscription (ID) of the offer to activate.basePlanId- Required. The parent base plan (ID) of the offer to activate.offerId- Required. The unique offer ID of the offer to activate.
Sourcepub fn subscriptions_base_plans_offers_batch_get(
&self,
request: BatchGetSubscriptionOffersRequest,
package_name: &str,
product_id: &str,
base_plan_id: &str,
) -> MonetizationSubscriptionBasePlanOfferBatchGetCall<'a, C>
pub fn subscriptions_base_plans_offers_batch_get( &self, request: BatchGetSubscriptionOffersRequest, package_name: &str, product_id: &str, base_plan_id: &str, ) -> MonetizationSubscriptionBasePlanOfferBatchGetCall<'a, C>
Create a builder to help you perform the following task:
Reads one or more subscription offers.
Arguments
request- No description provided.packageName- Required. The parent app (package name) for which the subscriptions should be created or updated. Must be equal to the package_name field on all the requests.productId- Required. The product ID of the parent subscription, if all updated offers belong to the same subscription. If this request spans multiple subscriptions, set this field to “-”. Must be set.basePlanId- Required. The parent base plan (ID) for which the offers should be read. May be specified as ‘-’ to read offers from multiple base plans.
Sourcepub fn subscriptions_base_plans_offers_batch_update(
&self,
request: BatchUpdateSubscriptionOffersRequest,
package_name: &str,
product_id: &str,
base_plan_id: &str,
) -> MonetizationSubscriptionBasePlanOfferBatchUpdateCall<'a, C>
pub fn subscriptions_base_plans_offers_batch_update( &self, request: BatchUpdateSubscriptionOffersRequest, package_name: &str, product_id: &str, base_plan_id: &str, ) -> MonetizationSubscriptionBasePlanOfferBatchUpdateCall<'a, C>
Create a builder to help you perform the following task:
Updates a batch of subscription offers. Set the latencyTolerance field on nested requests to PRODUCT_UPDATE_LATENCY_TOLERANCE_LATENCY_TOLERANT to achieve maximum update throughput.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the updated subscription offers. Must be equal to the package_name field on all the updated SubscriptionOffer resources.productId- Required. The product ID of the parent subscription, if all updated offers belong to the same subscription. If this request spans multiple subscriptions, set this field to “-”. Must be set.basePlanId- Required. The parent base plan (ID) for which the offers should be updated. May be specified as ‘-’ to update offers from multiple base plans.
Sourcepub fn subscriptions_base_plans_offers_batch_update_states(
&self,
request: BatchUpdateSubscriptionOfferStatesRequest,
package_name: &str,
product_id: &str,
base_plan_id: &str,
) -> MonetizationSubscriptionBasePlanOfferBatchUpdateStateCall<'a, C>
pub fn subscriptions_base_plans_offers_batch_update_states( &self, request: BatchUpdateSubscriptionOfferStatesRequest, package_name: &str, product_id: &str, base_plan_id: &str, ) -> MonetizationSubscriptionBasePlanOfferBatchUpdateStateCall<'a, C>
Create a builder to help you perform the following task:
Updates a batch of subscription offer states. Set the latencyTolerance field on nested requests to PRODUCT_UPDATE_LATENCY_TOLERANCE_LATENCY_TOLERANT to achieve maximum update throughput.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the updated subscription offers. Must be equal to the package_name field on all the updated SubscriptionOffer resources.productId- Required. The product ID of the parent subscription, if all updated offers belong to the same subscription. If this request spans multiple subscriptions, set this field to “-”. Must be set.basePlanId- Required. The parent base plan (ID) for which the offers should be updated. May be specified as ‘-’ to update offers from multiple base plans.
Sourcepub fn subscriptions_base_plans_offers_create(
&self,
request: SubscriptionOffer,
package_name: &str,
product_id: &str,
base_plan_id: &str,
) -> MonetizationSubscriptionBasePlanOfferCreateCall<'a, C>
pub fn subscriptions_base_plans_offers_create( &self, request: SubscriptionOffer, package_name: &str, product_id: &str, base_plan_id: &str, ) -> MonetizationSubscriptionBasePlanOfferCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates a new subscription offer. Only auto-renewing base plans can have subscription offers. The offer state will be DRAFT until it is activated.
Arguments
request- No description provided.packageName- Required. The parent app (package name) for which the offer should be created. Must be equal to the package_name field on the Subscription resource.productId- Required. The parent subscription (ID) for which the offer should be created. Must be equal to the product_id field on the SubscriptionOffer resource.basePlanId- Required. The parent base plan (ID) for which the offer should be created. Must be equal to the base_plan_id field on the SubscriptionOffer resource.
Sourcepub fn subscriptions_base_plans_offers_deactivate(
&self,
request: DeactivateSubscriptionOfferRequest,
package_name: &str,
product_id: &str,
base_plan_id: &str,
offer_id: &str,
) -> MonetizationSubscriptionBasePlanOfferDeactivateCall<'a, C>
pub fn subscriptions_base_plans_offers_deactivate( &self, request: DeactivateSubscriptionOfferRequest, package_name: &str, product_id: &str, base_plan_id: &str, offer_id: &str, ) -> MonetizationSubscriptionBasePlanOfferDeactivateCall<'a, C>
Create a builder to help you perform the following task:
Deactivates a subscription offer. Once deactivated, existing subscribers will maintain their subscription, but the offer will become unavailable to new subscribers.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the offer to deactivate.productId- Required. The parent subscription (ID) of the offer to deactivate.basePlanId- Required. The parent base plan (ID) of the offer to deactivate.offerId- Required. The unique offer ID of the offer to deactivate.
Sourcepub fn subscriptions_base_plans_offers_delete(
&self,
package_name: &str,
product_id: &str,
base_plan_id: &str,
offer_id: &str,
) -> MonetizationSubscriptionBasePlanOfferDeleteCall<'a, C>
pub fn subscriptions_base_plans_offers_delete( &self, package_name: &str, product_id: &str, base_plan_id: &str, offer_id: &str, ) -> MonetizationSubscriptionBasePlanOfferDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a subscription offer. Can only be done for draft offers. This action is irreversible.
Arguments
packageName- Required. The parent app (package name) of the offer to delete.productId- Required. The parent subscription (ID) of the offer to delete.basePlanId- Required. The parent base plan (ID) of the offer to delete.offerId- Required. The unique offer ID of the offer to delete.
Sourcepub fn subscriptions_base_plans_offers_get(
&self,
package_name: &str,
product_id: &str,
base_plan_id: &str,
offer_id: &str,
) -> MonetizationSubscriptionBasePlanOfferGetCall<'a, C>
pub fn subscriptions_base_plans_offers_get( &self, package_name: &str, product_id: &str, base_plan_id: &str, offer_id: &str, ) -> MonetizationSubscriptionBasePlanOfferGetCall<'a, C>
Create a builder to help you perform the following task:
Reads a single offer
Arguments
packageName- Required. The parent app (package name) of the offer to get.productId- Required. The parent subscription (ID) of the offer to get.basePlanId- Required. The parent base plan (ID) of the offer to get.offerId- Required. The unique offer ID of the offer to get.
Sourcepub fn subscriptions_base_plans_offers_list(
&self,
package_name: &str,
product_id: &str,
base_plan_id: &str,
) -> MonetizationSubscriptionBasePlanOfferListCall<'a, C>
pub fn subscriptions_base_plans_offers_list( &self, package_name: &str, product_id: &str, base_plan_id: &str, ) -> MonetizationSubscriptionBasePlanOfferListCall<'a, C>
Create a builder to help you perform the following task:
Lists all offers under a given subscription.
Arguments
packageName- Required. The parent app (package name) for which the subscriptions should be read.productId- Required. The parent subscription (ID) for which the offers should be read. May be specified as ‘-’ to read all offers under an app.basePlanId- Required. The parent base plan (ID) for which the offers should be read. May be specified as ‘-’ to read all offers under a subscription or an app. Must be specified as ‘-’ if product_id is specified as ‘-’.
Sourcepub fn subscriptions_base_plans_offers_patch(
&self,
request: SubscriptionOffer,
package_name: &str,
product_id: &str,
base_plan_id: &str,
offer_id: &str,
) -> MonetizationSubscriptionBasePlanOfferPatchCall<'a, C>
pub fn subscriptions_base_plans_offers_patch( &self, request: SubscriptionOffer, package_name: &str, product_id: &str, base_plan_id: &str, offer_id: &str, ) -> MonetizationSubscriptionBasePlanOfferPatchCall<'a, C>
Create a builder to help you perform the following task:
Updates an existing subscription offer.
Arguments
request- No description provided.packageName- Required. Immutable. The package name of the app the parent subscription belongs to.productId- Required. Immutable. The ID of the parent subscription this offer belongs to.basePlanId- Required. Immutable. The ID of the base plan to which this offer is an extension.offerId- Required. Immutable. Unique ID of this subscription offer. Must be unique within the base plan.
Sourcepub fn subscriptions_base_plans_activate(
&self,
request: ActivateBasePlanRequest,
package_name: &str,
product_id: &str,
base_plan_id: &str,
) -> MonetizationSubscriptionBasePlanActivateCall<'a, C>
pub fn subscriptions_base_plans_activate( &self, request: ActivateBasePlanRequest, package_name: &str, product_id: &str, base_plan_id: &str, ) -> MonetizationSubscriptionBasePlanActivateCall<'a, C>
Create a builder to help you perform the following task:
Activates a base plan. Once activated, base plans will be available to new subscribers.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the base plan to activate.productId- Required. The parent subscription (ID) of the base plan to activate.basePlanId- Required. The unique base plan ID of the base plan to activate.
Sourcepub fn subscriptions_base_plans_batch_migrate_prices(
&self,
request: BatchMigrateBasePlanPricesRequest,
package_name: &str,
product_id: &str,
) -> MonetizationSubscriptionBasePlanBatchMigratePriceCall<'a, C>
pub fn subscriptions_base_plans_batch_migrate_prices( &self, request: BatchMigrateBasePlanPricesRequest, package_name: &str, product_id: &str, ) -> MonetizationSubscriptionBasePlanBatchMigratePriceCall<'a, C>
Create a builder to help you perform the following task:
Batch variant of the MigrateBasePlanPrices endpoint. Set the latencyTolerance field on nested requests to PRODUCT_UPDATE_LATENCY_TOLERANCE_LATENCY_TOLERANT to achieve maximum update throughput.
Arguments
request- No description provided.packageName- Required. The parent app (package name) for which the subscriptions should be created or updated. Must be equal to the package_name field on all the Subscription resources.productId- Required. The product ID of the parent subscription, if all updated offers belong to the same subscription. If this batch update spans multiple subscriptions, set this field to “-”. Must be set.
Sourcepub fn subscriptions_base_plans_batch_update_states(
&self,
request: BatchUpdateBasePlanStatesRequest,
package_name: &str,
product_id: &str,
) -> MonetizationSubscriptionBasePlanBatchUpdateStateCall<'a, C>
pub fn subscriptions_base_plans_batch_update_states( &self, request: BatchUpdateBasePlanStatesRequest, package_name: &str, product_id: &str, ) -> MonetizationSubscriptionBasePlanBatchUpdateStateCall<'a, C>
Create a builder to help you perform the following task:
Activates or deactivates base plans across one or multiple subscriptions. Set the latencyTolerance field on nested requests to PRODUCT_UPDATE_LATENCY_TOLERANCE_LATENCY_TOLERANT to achieve maximum update throughput.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the updated base plans.productId- Required. The product ID of the parent subscription, if all updated base plans belong to the same subscription. If this batch update spans multiple subscriptions, set this field to “-”. Must be set.
Sourcepub fn subscriptions_base_plans_deactivate(
&self,
request: DeactivateBasePlanRequest,
package_name: &str,
product_id: &str,
base_plan_id: &str,
) -> MonetizationSubscriptionBasePlanDeactivateCall<'a, C>
pub fn subscriptions_base_plans_deactivate( &self, request: DeactivateBasePlanRequest, package_name: &str, product_id: &str, base_plan_id: &str, ) -> MonetizationSubscriptionBasePlanDeactivateCall<'a, C>
Create a builder to help you perform the following task:
Deactivates a base plan. Once deactivated, the base plan will become unavailable to new subscribers, but existing subscribers will maintain their subscription
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the base plan to deactivate.productId- Required. The parent subscription (ID) of the base plan to deactivate.basePlanId- Required. The unique base plan ID of the base plan to deactivate.
Sourcepub fn subscriptions_base_plans_delete(
&self,
package_name: &str,
product_id: &str,
base_plan_id: &str,
) -> MonetizationSubscriptionBasePlanDeleteCall<'a, C>
pub fn subscriptions_base_plans_delete( &self, package_name: &str, product_id: &str, base_plan_id: &str, ) -> MonetizationSubscriptionBasePlanDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a base plan. Can only be done for draft base plans. This action is irreversible.
Arguments
packageName- Required. The parent app (package name) of the base plan to delete.productId- Required. The parent subscription (ID) of the base plan to delete.basePlanId- Required. The unique offer ID of the base plan to delete.
Sourcepub fn subscriptions_base_plans_migrate_prices(
&self,
request: MigrateBasePlanPricesRequest,
package_name: &str,
product_id: &str,
base_plan_id: &str,
) -> MonetizationSubscriptionBasePlanMigratePriceCall<'a, C>
pub fn subscriptions_base_plans_migrate_prices( &self, request: MigrateBasePlanPricesRequest, package_name: &str, product_id: &str, base_plan_id: &str, ) -> MonetizationSubscriptionBasePlanMigratePriceCall<'a, C>
Create a builder to help you perform the following task:
Migrates subscribers from one or more legacy price cohorts to the current price. Requests result in Google Play notifying affected subscribers. Only up to 250 simultaneous legacy price cohorts are supported.
Arguments
request- No description provided.packageName- Required. Package name of the parent app. Must be equal to the package_name field on the Subscription resource.productId- Required. The ID of the subscription to update. Must be equal to the product_id field on the Subscription resource.basePlanId- Required. The unique base plan ID of the base plan to update prices on.
Sourcepub fn subscriptions_archive(
&self,
request: ArchiveSubscriptionRequest,
package_name: &str,
product_id: &str,
) -> MonetizationSubscriptionArchiveCall<'a, C>
pub fn subscriptions_archive( &self, request: ArchiveSubscriptionRequest, package_name: &str, product_id: &str, ) -> MonetizationSubscriptionArchiveCall<'a, C>
Create a builder to help you perform the following task:
Deprecated: subscription archiving is not supported.
Arguments
request- No description provided.packageName- Required. The parent app (package name) of the app of the subscription to delete.productId- Required. The unique product ID of the subscription to delete.
Sourcepub fn subscriptions_batch_get(
&self,
package_name: &str,
) -> MonetizationSubscriptionBatchGetCall<'a, C>
pub fn subscriptions_batch_get( &self, package_name: &str, ) -> MonetizationSubscriptionBatchGetCall<'a, C>
Create a builder to help you perform the following task:
Reads one or more subscriptions.
Arguments
packageName- Required. The parent app (package name) for which the subscriptions should be retrieved. Must be equal to the package_name field on all the requests.
Sourcepub fn subscriptions_batch_update(
&self,
request: BatchUpdateSubscriptionsRequest,
package_name: &str,
) -> MonetizationSubscriptionBatchUpdateCall<'a, C>
pub fn subscriptions_batch_update( &self, request: BatchUpdateSubscriptionsRequest, package_name: &str, ) -> MonetizationSubscriptionBatchUpdateCall<'a, C>
Create a builder to help you perform the following task:
Updates a batch of subscriptions. Set the latencyTolerance field on nested requests to PRODUCT_UPDATE_LATENCY_TOLERANCE_LATENCY_TOLERANT to achieve maximum update throughput.
Arguments
request- No description provided.packageName- Required. The parent app (package name) for which the subscriptions should be updated. Must be equal to the package_name field on all the Subscription resources.
Sourcepub fn subscriptions_create(
&self,
request: Subscription,
package_name: &str,
) -> MonetizationSubscriptionCreateCall<'a, C>
pub fn subscriptions_create( &self, request: Subscription, package_name: &str, ) -> MonetizationSubscriptionCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates a new subscription. Newly added base plans will remain in draft state until activated.
Arguments
request- No description provided.packageName- Required. The parent app (package name) for which the subscription should be created. Must be equal to the package_name field on the Subscription resource.
Sourcepub fn subscriptions_delete(
&self,
package_name: &str,
product_id: &str,
) -> MonetizationSubscriptionDeleteCall<'a, C>
pub fn subscriptions_delete( &self, package_name: &str, product_id: &str, ) -> MonetizationSubscriptionDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a subscription. A subscription can only be deleted if it has never had a base plan published.
Arguments
packageName- Required. The parent app (package name) of the app of the subscription to delete.productId- Required. The unique product ID of the subscription to delete.
Sourcepub fn subscriptions_get(
&self,
package_name: &str,
product_id: &str,
) -> MonetizationSubscriptionGetCall<'a, C>
pub fn subscriptions_get( &self, package_name: &str, product_id: &str, ) -> MonetizationSubscriptionGetCall<'a, C>
Create a builder to help you perform the following task:
Reads a single subscription.
Arguments
packageName- Required. The parent app (package name) of the subscription to get.productId- Required. The unique product ID of the subscription to get.
Sourcepub fn subscriptions_list(
&self,
package_name: &str,
) -> MonetizationSubscriptionListCall<'a, C>
pub fn subscriptions_list( &self, package_name: &str, ) -> MonetizationSubscriptionListCall<'a, C>
Create a builder to help you perform the following task:
Lists all subscriptions under a given app.
Arguments
packageName- Required. The parent app (package name) for which the subscriptions should be read.
Sourcepub fn subscriptions_patch(
&self,
request: Subscription,
package_name: &str,
product_id: &str,
) -> MonetizationSubscriptionPatchCall<'a, C>
pub fn subscriptions_patch( &self, request: Subscription, package_name: &str, product_id: &str, ) -> MonetizationSubscriptionPatchCall<'a, C>
Create a builder to help you perform the following task:
Updates an existing subscription.
Arguments
request- No description provided.packageName- Immutable. Package name of the parent app.productId- Immutable. Unique product ID of the product. Unique within the parent app. Product IDs must be composed of lower-case letters (a-z), numbers (0-9), underscores (_) and dots (.). It must start with a lower-case letter or number, and be between 1 and 40 (inclusive) characters in length.
Sourcepub fn convert_region_prices(
&self,
request: ConvertRegionPricesRequest,
package_name: &str,
) -> MonetizationConvertRegionPriceCall<'a, C>
pub fn convert_region_prices( &self, request: ConvertRegionPricesRequest, package_name: &str, ) -> MonetizationConvertRegionPriceCall<'a, C>
Create a builder to help you perform the following task:
Calculates the region prices, using today’s exchange rate and country-specific pricing patterns, based on the price in the request for a set of regions.
Arguments
request- No description provided.packageName- Required. The app package name.