pub struct OneTimeProductPurchaseOption {
pub buy_option: Option<OneTimeProductBuyPurchaseOption>,
pub new_regions_config: Option<OneTimeProductPurchaseOptionNewRegionsConfig>,
pub offer_tags: Option<Vec<OfferTag>>,
pub purchase_option_id: Option<String>,
pub regional_pricing_and_availability_configs: Option<Vec<OneTimeProductPurchaseOptionRegionalPricingAndAvailabilityConfig>>,
pub rent_option: Option<OneTimeProductRentPurchaseOption>,
pub state: Option<String>,
pub tax_and_compliance_settings: Option<PurchaseOptionTaxAndComplianceSettings>,
}Expand description
A single purchase option for a one-time product.
This type is not used in any activity, and only used as part of another schema.
Fields
buy_option: Option<OneTimeProductBuyPurchaseOption>A purchase option that can be bought.
new_regions_config: Option<OneTimeProductPurchaseOptionNewRegionsConfig>Pricing information for any new locations Play may launch in the future. If omitted, the purchase option will not be automatically available in any new locations Play may launch in the future.
Optional. List of up to 20 custom tags specified for this purchase option, and returned to the app through the billing library. Offers for this purchase option will also receive these tags in the billing library.
purchase_option_id: Option<String>Required. Immutable. The unique identifier of this purchase option. Must be unique within the one-time product. It must start with a number or lower-case letter, and can only contain lower-case letters (a-z), numbers (0-9), and hyphens (-). The maximum length is 63 characters.
regional_pricing_and_availability_configs: Option<Vec<OneTimeProductPurchaseOptionRegionalPricingAndAvailabilityConfig>>Regional pricing and availability information for this purchase option.
rent_option: Option<OneTimeProductRentPurchaseOption>A purchase option that can be rented.
state: Option<String>Output only. The state of the purchase option, i.e., whether it’s active. This field cannot be changed by updating the resource. Use the dedicated endpoints instead.
tax_and_compliance_settings: Option<PurchaseOptionTaxAndComplianceSettings>Optional. Details about taxes and legal compliance.