pub struct ProductOfferDetails {
pub consumption_state: Option<String>,
pub offer_id: Option<String>,
pub offer_tags: Option<Vec<String>>,
pub offer_token: Option<String>,
pub preorder_offer_details: Option<PreorderOfferDetails>,
pub purchase_option_id: Option<String>,
pub quantity: Option<i32>,
pub refundable_quantity: Option<i32>,
pub rent_offer_details: Option<RentOfferDetails>,
}Expand description
Offer details information related to a purchase line item.
This type is not used in any activity, and only used as part of another schema.
Fields
consumption_state: Option<String>Output only. The consumption state of the purchase.
offer_id: Option<String>The offer ID. Only present for offers.
The latest offer tags associated with the offer. It includes tags inherited from the purchase option.
offer_token: Option<String>The per-transaction offer token used to make this purchase line item.
preorder_offer_details: Option<PreorderOfferDetails>Offer details for a preorder offer. This will only be set for preorders.
purchase_option_id: Option<String>The purchase option ID.
quantity: Option<i32>The quantity associated with the purchase of the inapp product.
refundable_quantity: Option<i32>The quantity eligible for refund, i.e. quantity that hasn’t been refunded. The value reflects quantity-based partial refunds and full refunds.
rent_offer_details: Option<RentOfferDetails>Offer details about rent offers. This will only be set for rental line items.