pub struct TargetingRuleScope {
pub any_subscription_in_app: Option<TargetingRuleScopeAnySubscriptionInApp>,
pub specific_subscription_in_app: Option<String>,
pub this_subscription: Option<TargetingRuleScopeThisSubscription>,
}Expand description
Defines the scope of subscriptions which a targeting rule can match to target offers to users based on past or current entitlement.
This type is not used in any activity, and only used as part of another schema.
Fields
any_subscription_in_app: Option<TargetingRuleScopeAnySubscriptionInApp>The scope of the current targeting rule is any subscription in the parent app.
specific_subscription_in_app: Option<String>The scope of the current targeting rule is the subscription with the specified subscription ID. Must be a subscription within the same parent app.
this_subscription: Option<TargetingRuleScopeThisSubscription>The scope of the current targeting rule is the subscription in which this offer is defined.