pub struct VoidedPurchase {
pub kind: Option<String>,
pub order_id: Option<String>,
pub purchase_time_millis: Option<i64>,
pub purchase_token: Option<String>,
pub voided_quantity: Option<i32>,
pub voided_reason: Option<i32>,
pub voided_source: Option<i32>,
pub voided_time_millis: Option<i64>,
}Expand description
A VoidedPurchase resource indicates a purchase that was either canceled/refunded/charged-back.
This type is not used in any activity, and only used as part of another schema.
Fields
kind: Option<String>This kind represents a voided purchase object in the androidpublisher service.
order_id: Option<String>The order id which uniquely identifies a one-time purchase, subscription purchase, or subscription renewal.
purchase_time_millis: Option<i64>The time at which the purchase was made, in milliseconds since the epoch (Jan 1, 1970).
purchase_token: Option<String>The token which uniquely identifies a one-time purchase or subscription. To uniquely identify subscription renewals use order_id (available starting from version 3 of the API).
voided_quantity: Option<i32>The voided quantity as the result of a quantity-based partial refund. Voided purchases of quantity-based partial refunds may only be returned when includeQuantityBasedPartialRefund is set to true.
voided_reason: Option<i32>The reason why the purchase was voided, possible values are: 0. Other 1. Remorse 2. Not_received 3. Defective 4. Accidental_purchase 5. Fraud 6. Friendly_fraud 7. Chargeback 8. Unacknowledged_purchase
voided_source: Option<i32>The initiator of voided purchase, possible values are: 0. User 1. Developer 2. Google
voided_time_millis: Option<i64>The time at which the purchase was canceled/refunded/charged-back, in milliseconds since the epoch (Jan 1, 1970).